@@ -9,10 +9,10 @@
 #define __FTWX_H
 
 /*
- * $Id: ftwx.h,v 2.1 1992/10/01 00:41:02 panos Exp $
+ * $Id: ftwx.h,v 1.1.1.1 1999/10/12 17:28:59 bbraun Exp $
  */
 
-#ifndef __FTWX_NO_FTW
+#ifdef HAVE_FTW_H
 #include <ftw.h>
 #else
 #define FTW_F   0
@@ -29,17 +29,7 @@
 #define FTWX_FOLLOW     0x1
 
 
-#ifdef __ARGS
-#undef _ARGS
-#endif
-
-#ifdef PROTOTYPES
-#  define __ARGS( s )               s
-#else
-#  define __ARGS( s )               ()
-#endif
-
-int ftwx __ARGS( ( char *path, int (*func)(), int depth, int flags ) ) ;
+int ftwx ( char *path, int (*func)(), int depth, int flags ) ;
 
 #endif 	/* __FTWX_H */
 
