@@ -4,13 +4,20 @@
  * and conditions for redistribution.
  */
 
-static char RCSid[] = "$Id: hpq.c,v 1.5 1995/09/10 18:33:46 chuck Exp $" ;
-static char version[] = VERSION ;
+static char RCSid[] = "$Id: hpq.c,v 1.2 1999/10/15 04:32:18 bbraun Exp $" ;
+#include "config.h"
+#ifdef PQ_VERSION
+static char version[] = PQ_VERSION ;
+#endif
 
-#include <sys/param.h>
+#include <stdlib.h>
+#include <unistd.h>
+#include <string.h>
 #include "pq.h"
 #include "hpqimpl.h"
 
+int pq_errno;
+
 #define PRIVATE			static
 
 #ifndef NULL
@@ -18,39 +25,33 @@ static char version[] = VERSION ;
 #endif
 
 #define PARENT( i )		( i >> 1 )
-#define LEFT( i )			( i << 1 )
+#define LEFT( i )		( i << 1 )
 #define RIGHT( i )		( LEFT( i ) + 1 )
 
-int pq_errno ;
-
 #define INITIAL_ARRAY_SIZE				100				/* entries */
 
-#if defined(linux) || defined(BSD)
-PRIVATE int grow( header_s *hp ) ;
-PRIVATE void restore_heap( register header_s *hp , unsigned start ) ;
-#endif
+PRIVATE int grow( header_s *hp );
+PRIVATE void restore_heap( header_s *hp, unsigned start );
 
-pq_h __hpq_create( func, flags, errnop )
-	int (*func)() ;
-	int flags ;
-	int *errnop ;
+pq_h __hpq_create( int (*func)(), int flags, int *errnop )
 {
-	register header_s *hp ;
+	header_s *hp ;
 	int *errp = ( errnop == NULL ) ? &pq_errno : errnop ;
-	char *malloc() ;
 
 	/*
 	 * Check if the user has provided the necessary comparison functions
 	 */
-	if ( func == NULL )
+	if ( func == NULL ) {
 		HANDLE_ERROR( flags, NULL, errp, PQ_ENOFUNC,
 				"HPQ __hpq_create: missing object-object comparator\n" ) ;
+	}
 
 	hp = HHP( malloc( sizeof( header_s ) ) ) ;
-	if ( hp == NULL )
+	if ( hp == NULL ) {
 		HANDLE_ERROR( flags, NULL, errp, PQ_ENOMEM,
 												"HPQ __hpq_create: malloc failed\n" ) ;
-	
+	}
+
 	/*
 	 * Allocate object array
 	 */
@@ -58,7 +59,7 @@ pq_h __hpq_create( func, flags, errnop )
 	if ( hp->objects == NULL )
 	{
 		free( (char *)hp ) ;
-		HANDLE_ERROR( flags, NULL, errp, PQ_ENOMEM, 
+		HANDLE_ERROR( flags, NULL, errp, PQ_ENOMEM,
 												"HPQ __hpq_create: malloc failed\n" ) ;
 	}
 
@@ -74,8 +75,7 @@ pq_h __hpq_create( func, flags, errnop )
 }
 
 
-void __hpq_destroy( handle )
-	pq_h handle ;
+void __hpq_destroy( pq_h handle )
 {
 	header_s *hp = HHP( handle ) ;
 
@@ -84,16 +84,15 @@ void __hpq_destroy( handle )
 }
 
 
-int __hpq_insert( handle, object )
-	pq_h handle ;
-	pq_obj object ;
+int __hpq_insert( pq_h handle, pq_obj object )
 {
-	register header_s *hp = HHP( handle ) ;
-	register unsigned i, parent ;
+	header_s *hp = HHP( handle ) ;
+	unsigned i, parent ;
 
-	if ( object == NULL )
+	if ( object == NULL ) {
 		HANDLE_ERROR( hp->flags, PQ_ERR, hp->errnop, PQ_ENULLOBJECT,
 											"HPQ __hpq_insert: NULL object\n" ) ;
+	}
 
 	/*
 	 * Make sure there is room to store the object
@@ -120,16 +119,14 @@ int __hpq_insert( handle, object )
 /*
  * Grow the table.
  * Algorithm:
- *			while the table_size is less than CUTOFF, double the size.
+ *		while the table_size is less than CUTOFF, double the size.
  * 		if it grows greater than CUTOFF, increase the size by INCREMENT
  *			(these number are in entries, not bytes)
  */
-PRIVATE int grow( hp )
-	header_s *hp ;
+PRIVATE int grow( header_s *hp )
 {
 	unsigned new_size ;
 	char *new_objects ;
-	char *realloc() ;
 
 	if ( hp->max_size < CUTOFF )
 		new_size = hp->max_size * 2 ;
@@ -137,9 +134,10 @@ PRIVATE int grow( hp )
 		new_size = hp->max_size + INCREMENT ;
 
 	new_objects = realloc( (char *)hp->objects, new_size * sizeof( pq_obj ) ) ;
-	if ( new_objects == NULL )
+	if ( new_objects == NULL ) {
 		HANDLE_ERROR( hp->flags, PQ_ERR, hp->errnop, PQ_ENOMEM,
 										"HPQ grow: out of memory\n" ) ;
+	}
 	
 	hp->max_size = new_size ;
 	hp->objects = (pq_obj *) new_objects ;
@@ -147,16 +145,14 @@ PRIVATE int grow( hp )
 }
 
 
-pq_obj __hpq_extract_head( handle )
-	pq_h handle ;
+pq_obj __hpq_extract_head( pq_h handle )
 {
-	register header_s *hp = HHP( handle ) ;
+	header_s *hp = HHP( handle ) ;
 	pq_obj object ;
-	void restore_heap() ;
 
 	if ( hp->cur_size == 0 )
 		return( NULL ) ;
-	
+
 	object = hp->objects[ 0 ] ;
 	hp->objects[ 0 ] = hp->objects[ --hp->cur_size ] ;
 	restore_heap( hp, 0 ) ;
@@ -167,24 +163,22 @@ pq_obj __hpq_extract_head( handle )
 #define EXISTS( hp, i )				( i < hp->cur_size )
 #define IS_BETTER( hp, i, j )		\
 			( (*hp->is_better)( hp->objects[ i ], hp->objects[ j ] ) )
-#define SWAP( hp, i, j )								\
-		{														\
-			pq_obj t = hp->objects[ i ] ;				\
+#define SWAP( hp, i, j )							\
+		{									\
+			pq_obj t = hp->objects[ i ] ;			\
 			hp->objects[ i ] = hp->objects[ j ] ;	\
-			hp->objects[ j ] = t ;						\
+			hp->objects[ j ] = t ;				\
 		}
 
-PRIVATE void restore_heap( hp, start )
-	register header_s *hp ;
-	unsigned start ;
+PRIVATE void restore_heap( header_s *hp, unsigned start )
 {
-	register unsigned current = start ;
-	register unsigned better = current ;
+	unsigned current = start ;
+	unsigned better = current ;
 
 	for ( ;; )
 	{
-		register unsigned left = LEFT( current ) ;
-		register unsigned right = RIGHT( current ) ;
+		unsigned left = LEFT( current ) ;
+		unsigned right = RIGHT( current ) ;
 
 		/*
 		 * Meaning of variables:
@@ -208,7 +202,7 @@ PRIVATE void restore_heap( hp, start )
 
 		if ( better == current || IS_BETTER( hp, current, better ) )
 			break ;
-		else 
+		else
 		{
 			SWAP( hp, current, better ) ;
 			current = better ;
@@ -217,16 +211,15 @@ PRIVATE void restore_heap( hp, start )
 }
 
 
-int __hpq_delete( handle, object )
-	pq_h handle ;
-	register pq_obj object ;
+int __hpq_delete( pq_h handle, pq_obj object )
 {
-	register header_s *hp = HHP( handle ) ;
-	register unsigned i ;
+	header_s *hp = HHP( handle ) ;
+	unsigned i ;
 
-	if ( object == NULL )
+	if ( object == NULL ) {
 		HANDLE_ERROR( hp->flags, PQ_ERR, hp->errnop, PQ_ENULLOBJECT,
 											"HPQ __hpq_delete: NULL object\n" ) ;
+	}
 
 	/*
 	 * First find it
@@ -238,9 +231,10 @@ int __hpq_delete( handle, object )
 				break ;
 			else
 				continue ;
-		else
+		else {
 			HANDLE_ERROR( hp->flags, PQ_ERR, hp->errnop, PQ_ENOTFOUND,
 					"HPQ __hpq_delete: object not found\n" ) ;
+		}
 	}
 
 	hp->objects[ i ] = hp->objects[ --hp->cur_size ] ;
