@@ -15,11 +15,11 @@
  * Implementation of the PQ interface
  */
 
-#define pq_create				__hpq_create
+#define pq_create			__hpq_create
 #define pq_destroy			__hpq_destroy
-#define pq_insert				__hpq_insert
-#define pq_delete				__hpq_delete
-#define pq_head				__hpq_head
+#define pq_insert			__hpq_insert
+#define pq_delete			__hpq_delete
+#define pq_head			__hpq_head
 #define pq_extract_head		__hpq_extract_head
 
 /*
@@ -40,26 +40,18 @@ struct __hpq_header
 } ;
 
 
-#ifndef __ARGS
-#  ifdef PROTOTYPES
-#     define __ARGS( s )               s
-#  else
-#     define __ARGS( s )               ()
-#  endif
-#endif
+pq_h __hpq_create( int (*func)(), int flags, int *errnop ) ;
+void __hpq_destroy( pq_h handle ) ;
+int  __hpq_insert( pq_h handle, pq_obj object ) ;
+pq_obj __hpq_extract_head( pq_h handle ) ;
+int  __hpq_delete( pq_h handle, pq_obj object ) ;
 
-pq_h __hpq_create			__ARGS( ( int (*func)(), int flags, int *errnop ) ) ;
-void __hpq_destroy		__ARGS( ( pq_h handle ) ) ;
-int  __hpq_insert			__ARGS( ( pq_h handle, pq_obj object ) ) ;
-pq_obj __hpq_extract_head __ARGS( ( pq_h handle ) ) ;
-int  __hpq_delete 		__ARGS( ( pq_h handle, pq_obj object ) ) ;
+#define __hpq_head( handle )										\
+	(														\
+		((struct __hpq_header *)(handle))->cur_size					\
+				? ((struct __hpq_header *)(handle))->objects[ 0 ]		\
+				: (pq_obj) 0									\
+	)
 
-#define __hpq_head( handle )																\
-				(																					\
-					((struct __hpq_header *)(handle))->cur_size						\
-							? ((struct __hpq_header *)(handle))->objects[ 0 ] 		\
-							: (pq_obj) 0														\
-				)
-
-#endif __HPQ_H
+#endif /* __HPQ_H */
 
