@@ -4,8 +4,11 @@
  * and conditions for redistribution.
  */
 
-static char RCSid[] = "$Id: pq.c,v 1.1 1992/11/23 16:25:25 panos Exp $" ;
-static char version[] = VERSION ;
+static char RCSid[] = "$Id: pq.c,v 1.1.1.1 1999/10/12 17:28:59 bbraun Exp $" ;
+#include "config.h"
+#ifdef PQ_VERSION
+static char version[] = PQ_VERSION ;
+#endif
 
 int pq_errno ;
 
