@@ -4,29 +4,25 @@
  * and conditions for redistribution.
  */
 
-static char RCSid[] = "$Id: pset.c,v 3.1 1993/03/06 18:48:57 panos Exp $" ;
-static char version[] = VERSION ;
+static char RCSid[] = "$Id: pset.c,v 1.1.1.1 1999/10/12 17:28:59 bbraun Exp $" ;
+#include "config.h"
+#ifdef PSET_VERSION
+static char version[] = PSET_VERSION ;
+#endif
 
+#include <stdlib.h>
 #include "pset.h"
 
-#ifndef NULL
-#define NULL						0
-#endif
 
 #define ALLOC_START				20
 #define ALLOC_STEP				10
 
-#define POINTER					__pset_pointer
-
-char *malloc(), *realloc() ;
-
 
 /*
  * Create a pointer set and return a handle to it.
  * Some space is initially allocated for the set.
  */
-pset_h pset_create( alloc_start, alloc_step )
-	unsigned alloc_start, alloc_step ;
+pset_h pset_create( unsigned alloc_start, unsigned alloc_step )
 {
 	pset_h pset ;
 	unsigned start ;
@@ -36,7 +32,7 @@ pset_h pset_create( alloc_start, alloc_step )
 		return( NULL ) ;
 	
 	start = ( alloc_start == 0 ) ? ALLOC_START : alloc_start ;
-	pset->ptrs = (POINTER *) malloc( start * sizeof( POINTER ) ) ;
+	pset->ptrs = (__pset_pointer *) malloc( start * sizeof( __pset_pointer ) ) ;
 	if ( pset->ptrs == NULL )
 	{
 		free( (char *) pset ) ;
@@ -53,8 +49,7 @@ pset_h pset_create( alloc_start, alloc_step )
 /*
  * Destroy a pset
  */
-void pset_destroy( pset )
-	pset_h pset ;
+void pset_destroy( pset_h pset )
 {
 	free( (char *) pset->ptrs ) ;
 	free( (char *) pset ) ;
@@ -62,19 +57,17 @@ void pset_destroy( pset )
 
 
 /*
- * Insert a pointer to a pset
+ * Append a pointer to a pset
  */
-POINTER pset_insert( pset, p )
-	pset_h pset ;
-	POINTER p ;
+__pset_pointer pset_insert( pset_h pset, __pset_pointer p )
 {
 	if ( pset->count >= pset->max )
 	{
 		unsigned new_max = pset->max + pset->alloc_step ;
-		POINTER *new_ptrs ;
+		__pset_pointer *new_ptrs ;
 
-		new_ptrs = (POINTER *) realloc(
-								(char *)pset->ptrs, new_max * sizeof( POINTER ) ) ;
+		new_ptrs = (__pset_pointer *) realloc(
+			(char *)pset->ptrs, new_max * sizeof( __pset_pointer ) ) ;
 		if ( new_ptrs == NULL )
 			return( NULL ) ;
 		pset->max = new_max ;
@@ -87,33 +80,30 @@ POINTER pset_insert( pset, p )
 /*
  * Remove a pointer from a pset
  */
-void pset_delete( pset, ptr )
-	register pset_h pset ;
-	register POINTER ptr ;
+void pset_delete( register pset_h pset, register __pset_pointer ptr )
 {
-	register unsigned u = pset->count ;
+	register unsigned u = 0;
+	register int found_it = 0;
 
-	if ( u == 0 )
+	if ( pset->count == 0 )
 		return ;
-	
-	do
+
+	while ( u < pset->count )
 	{
-		u-- ;
 		if ( pset->ptrs[ u ] == ptr )
-		{
-			pset->ptrs[ u ] = pset->ptrs[ --pset->count ] ;
-			return ;
-		}
+			found_it = 1;
+		if ( found_it )
+			pset->ptrs[ u ] = pset->ptrs[ u+1 ];
+		u++;
 	}
-	while ( u ) ;
+	pset->count--;
 }
 
 
 /*
  * Create a pset iterator
  */
-psi_h psi_create( pset )
-	pset_h pset ;
+psi_h psi_create( pset_h pset )
 {
 	psi_h iter = (psi_h) malloc( sizeof( struct __pset_iterator ) ) ;
 
@@ -123,4 +113,3 @@ psi_h psi_create( pset )
 	return( iter ) ;
 }
 
-
