@@ -5,14 +5,15 @@
  */
 
 /*
- * $Id: impl.h,v 1.6 1995/09/10 18:42:47 chuck Exp $
+ * $Id: impl.h,v 1.1.1.1 1999/10/12 17:28:59 bbraun Exp $
  */
 
 #ifndef SIO_BUFFER_SIZE
 
 #include "sioconf.h"
+#include "sio.h"
 
-#ifdef HAS_MMAP
+#ifdef HAVE_MMAP
 #include <sys/types.h>
 
 
@@ -59,7 +60,7 @@ struct mmap_descriptor
 
 typedef struct mmap_descriptor mapd_s ;
 
-#endif /* HAS_MMAP */
+#endif /* HAVE_MMAP */
 
 typedef enum { FAILURE, SUCCESS } status_e ;
 
@@ -96,9 +97,6 @@ typedef enum { NO = 0, YES = 1 } boolean_e ;
 
 #define NUL								'\0'
 
-#ifdef PRIVATE
-#undef PRIVATE
-#endif
 #define PRIVATE						static
 
 #ifdef DEBUG
@@ -141,7 +139,6 @@ static char *itoa( num )
 
 
 #include <errno.h>
-extern int errno ;
 
 /*
  * IO_SETUP initializes a descriptor if it is not already initialized.
@@ -189,18 +186,22 @@ extern int errno ;
 /*
  * Internal functions that are visible
  */
-int __sio_readf(), __sio_writef(), __sio_pwritef() ;
-int __sio_extend_buffer(), __sio_init(), __sio_converter(), __sio_more() ;
-status_e __sio_switch() ;
+int __sio_readf( __sio_id_t *idp, int fd ) ;
+int __sio_writef( __sio_od_t *odp, int fd ) ;
+int __sio_pwritef() ;
+int __sio_extend_buffer( __sio_id_t *idp, int fd, int b_left ) ;
+int __sio_init( __sio_descriptor_t *dp, int fd, enum __sio_stream stream_type );
+int __sio_more( __sio_id_t *idp, int fd ) ;
+status_e __sio_switch( __sio_id_t *idp, int fd ) ;
 
 
-#ifdef HAS_MEMOPS
+#ifdef HAVE_MEMCPY
 #include <memory.h>
-#define sio_memcopy( from, to, nbytes )   	(void) memcpy( to, from, nbytes )
-#define sio_memscan( from, nbytes, ch )      memchr( from, ch, nbytes )
+#define sio_memcopy( from, to, nbytes )	(void) memcpy( to, from, nbytes )
+#define sio_memscan( from, nbytes, ch )   memchr( from, ch, nbytes )
 #endif
 
-#ifdef HAS_BCOPY
+#ifdef HAVE_BCOPY
 #define sio_memcopy( from, to, nbytes )      (void) bcopy( from, to, nbytes )
 #endif
 
@@ -211,12 +212,8 @@ void __sio_memcopy() ;
 #endif
 
 #ifndef sio_memscan
-#if defined(linux) || defined(__FreeBSD__) || defined(__bsdi__) || defined(__NetBSD__)
-PRIVATE char *sio_memscan( char *from , int how_many , register char ch ) ;
-#else
 char *sio_memscan() ;
 #endif
-#endif
 
 #endif /* SIO_BUFFER_SIZE */
 
