@@ -5,12 +5,22 @@
  */
 
 static char RCSid[] = "$Id: sio.c,v 1.1.1.1 1999/10/12 17:28:59 bbraun Exp $" ;
-static char sio_version[] = VERSION ;
+#include "config.h"
+#ifdef SIO_VERSION
+static char sio_version[] = SIO_VERSION ;
+#endif
+
 
 #ifndef linux
 #include <sys/types.h>
 #endif
 
+#ifdef _APPLE_
+#undef HAVE_MMAP
+#endif
+
+#include <stdlib.h>
+#include <unistd.h>
 #include <sys/stat.h>
 
 #include "sio.h"
