@@ -33,8 +33,8 @@
  * SIO_ERR: operation failed
  */
 #define SIO_FLUSH_ALL				(-1)
-#define SIO_EOF						(-2)
-#define SIO_ERR						(-1)
+#define SIO_EOF					(-2)
+#define SIO_ERR					(-1)
 
 /*
  * Undo types
@@ -47,7 +47,7 @@
  */
 #define SIO_FULLBUF			0
 #define SIO_LINEBUF			1
-#define SIO_NOBUF				2
+#define SIO_NOBUF			2
 
 /*
  * Descriptor for an input stream
@@ -132,18 +132,16 @@ typedef struct __sio_descriptor __sio_descriptor_t ;
  */
 extern __sio_descriptor_t *__sio_descriptors ;
 
-extern int errno ;
-
 
 /*
  * Internally used macros
  */
-#define __SIO_FD_INITIALIZED( fd )		(__sio_descriptors[ fd ].initialized)
+#define __SIO_FD_INITIALIZED( fd )	(__sio_descriptors[ fd ].initialized)
 #define __SIO_ID( fd )	(__sio_descriptors[ fd ].descriptor.input_descriptor)
 #define __SIO_OD( fd )	(__sio_descriptors[ fd ].descriptor.output_descriptor)
-#define __SIO_MUST_FLUSH( od, ch )													\
-					( (od).buftype != SIO_FULLBUF &&									\
-						( (od).buftype == SIO_NOBUF || ch == '\n' ) )
+#define __SIO_MUST_FLUSH( od, ch )				\
+			( (od).buftype != SIO_FULLBUF &&	\
+			( (od).buftype == SIO_NOBUF || ch == '\n' ) )
 
 
 /*
@@ -155,31 +153,30 @@ extern int errno ;
  *		Sgetchar( fd )
  *
  * NOTE: The maximum line size depends on whether the descriptor
- *			was originally memory mapped. If it was, then the maximum
- *			line size will be the map_unit_size (a function of the system
- *			page size and PAGES_MAPPED). Otherwise, it will be either the
- *			optimal block size as reported by stat(2) or SIO_BUFFER_SIZE.
+ *	was originally memory mapped. If it was, then the maximum
+ *	line size will be the map_unit_size (a function of the system
+ *	page size and PAGES_MAPPED). Otherwise, it will be either the
+ *	optimal block size as reported by stat(2) or SIO_BUFFER_SIZE.
  */
 
 #define SIOLINELEN( fd )      __SIO_ID( fd ).line_length
-#define SIOMAXLINELEN( fd )																	\
-	(																									\
-		__SIO_FD_INITIALIZED( fd )																\
-			? ( 																						\
-				 (__sio_descriptors[ fd ].stream_type == __SIO_INPUT_STREAM)		\
-					? __SIO_ID( fd ).max_line_length											\
-					: ( errno = EBADF, SIO_ERR )												\
-			  )																						\
-			: (		/* not initialized; initialize it for input */					\
-				 (__sio_init( &__sio_descriptors[ fd ], fd, __SIO_INPUT_STREAM )	\
-																					== SIO_ERR)		\
-					? SIO_ERR																		\
-					: __SIO_ID( fd ).max_line_length											\
-			  )																						\
+#define SIOMAXLINELEN( fd )				\
+   (							\
+  	__SIO_FD_INITIALIZED( fd )			\
+	? ( 					\
+	 (__sio_descriptors[ fd ].stream_type == __SIO_INPUT_STREAM)	\
+		? __SIO_ID( fd ).max_line_length		\
+		: ( errno = EBADF, SIO_ERR )			\
+	  )							\
+	: (		/* not initialized; initialize it for input */	\
+		 (__sio_init( &__sio_descriptors[ fd ], fd, __SIO_INPUT_STREAM )	\
+		== SIO_ERR)		\
+		? SIO_ERR		\
+		: __SIO_ID( fd ).max_line_length	\
+	  )						\
 	)
 
 
-
 /*
  * Adds a character to a buffer, returns the character or SIO_ERR
  */
@@ -217,40 +214,33 @@ extern int errno ;
 		)
 
 
-#ifdef __ARGS
-#undef __ARGS
-#endif
-
-#ifdef PROTOTYPES
-#	define __ARGS( s )					s
-#else
-#	define __ARGS( s )					()
-#endif
-
 /*
  * The Read functions
  */
-int Sread __ARGS( ( int fd, char *buf, int nbytes ) ) ;
-int Sgetc __ARGS( ( int fd ) ) ;
-char *Srdline __ARGS( ( int fd ) ) ;
-char *Sfetch __ARGS( ( int fd, long *length ) ) ;
+int Sread ( int fd, char *buf, int nbytes ) ;
+int Sgetc ( int fd ) ;
+char *Srdline ( int fd ) ;
+char *Sfetch ( int fd, long *length ) ;
 
 /*
  * The Write functions
  */
-int Swrite __ARGS( ( int fd, char *buf, int nbytes ) ) ;
-int Sputc __ARGS( ( int fd, char c ) ) ;
+int Swrite ( int fd, char *buf, int nbytes );
+int Sputc  ( int fd, char c ) ;
 int Sprint ( int fd, register char *format, ... ) ;
 int Sprintv ( int fd, char *format, va_list ap ) ;
 
 /*
  * other functions
  */
-int Sdone __ARGS( ( int fd ) ) ;
-int Sundo __ARGS( ( int fd, int type ) ) ;
-int Sflush __ARGS( ( int fd ) ) ;
-int Sclose __ARGS( ( int fd ) ) ;
-int Sbuftype __ARGS( ( int fd, int type ) ) ;
+int Sdone ( int fd ) ;
+int Sundo ( int fd, int type ) ;
+int Sflush ( int fd ) ;
+int Sclose ( int fd ) ;
+int Sbuftype ( int fd, int type ) ;
+int Smorefds ( void ) ;
+int __sio_converter( __sio_od_t *, int , char *, va_list );
+
 
 #endif /* __SIO_H */
 
