@@ -161,7 +161,7 @@
  *		2) only one of the BSD, SYS V flags is defined
  */
 #if !defined(HAVE_ISATTY) && !defined(HAVE_BSDTTY) && !defined(HAVE_SYSVTTY)
-ERROR function_isatty_not_available ;
+ #error function_isatty_not_available ;
 #endif
 
 #ifdef HAVE_ISATTY
@@ -170,7 +170,7 @@ ERROR function_isatty_not_available ;
 #endif
 
 #if defined(HAVE_BSDTTY) && defined(HAVE_SYSVTTY)
-ERROR HAVE_BSDTTY_and_HAVE_SYSVTTY_both_defined ;
+ #error HAVE_BSDTTY_and_HAVE_SYSVTTY_both_defined ;
 #endif
 
 
