@@ -4,12 +4,18 @@
  * and conditions for redistribution.
  */
 
-static char RCSid[] = "$Id: siosup.c,v 1.5 1995/09/10 18:35:09 chuck Exp $" ;
+static char RCSid[] = "$Id: siosup.c,v 1.1.1.1 1999/10/12 17:28:59 bbraun Exp $" ;
 
+#include "config.h"
 #include <sys/types.h>
-#include <sys/param.h>
 #include <sys/stat.h>
 #include <fcntl.h>
+#include <stdlib.h>
+#include <unistd.h>
+
+#ifdef _APPLE_
+#undef HAVE_MMAP
+#endif
 
 #include "impl.h"
 #include "sio.h"
@@ -18,40 +24,37 @@ static char RCSid[] = "$Id: siosup.c,v 1.5 1995/09/10 18:35:09 chuck Exp $" ;
 #include "events.h"
 #endif
 
-#if defined(BSD) || defined(linux)
-PRIVATE void terminate() ;
-PRIVATE status_e setup_read_buffer( register __sio_id_t *idp ,
-        unsigned buf_size );
-#endif
-char *malloc() ;
-char *realloc() ;
-
-
 static __sio_descriptor_t static_descriptor_array[ N_SIO_DESCRIPTORS ] ;
 static int n_descriptors = N_SIO_DESCRIPTORS ;
 __sio_descriptor_t *__sio_descriptors = static_descriptor_array ;
 
+PRIVATE void terminate(char *s);
+PRIVATE status_e setup_read_buffer( __sio_id_t *idp, unsigned buf_size );
+
 #ifdef EVENTS
 static events_s static___sio_events[ N_SIO_DESCRIPTORS ] ;
 events_s *__sio_events = static___sio_events ;
 #endif
 
+#ifndef MAP_FAILED
+#define MAP_FAILED ((void *)-1)
+#endif
 
 /*
  * Code for finalization
  */
-#ifdef HAS_FINALIZATION_FUNCTION
+#ifdef HAVE_FINALIZATION_FUNCTION
 static int finalizer_installed ;
 
 SIO_DEFINE_FIN( sio_cleanup )
 {
    (void) Sflush( SIO_FLUSH_ALL ) ;
 }
-#endif /* HAS_FINALIZATION_FUNCTION */
+#endif /* HAVE_FINALIZATION_FUNCTION */
 
 
 
-#ifdef HAS_MMAP
+#ifdef HAVE_MMAP
 
 #define CHAR_NULL				((char *)0)
 
@@ -73,9 +76,9 @@ static mapd_s *mmap_descriptors = static_mapd_array ;
  * NOTES ON MEMORY MAPPING:
  *
  * 	1. Memory mapping works only for file descriptors opened for input
- *		2. Mapping an object to a part of the address space where another
- *			object is mapped will cause the old mapping to disappear (i.e. mmap
- *			will not fail)
+ *	2. Mapping an object to a part of the address space where another
+ *	object is mapped will cause the old mapping to disappear (i.e. mmap
+ *	will not fail)
  *
  * Memory mapping interface:
  *		SIO_MMAP : maps a file into a portion of the address space.
@@ -96,8 +99,8 @@ static mapd_s *mmap_descriptors = static_mapd_array ;
 /*
  * Macros used by the memory mapping code
  */
-#define FIRST_TIME( dp )					( dp->buf == NULL )
-#define FATAL_ERROR( msg )					perror( msg ), exit( 1 )
+#define FIRST_TIME( dp )		( dp->buf == NULL )
+#define FATAL_ERROR( msg )		perror( msg ), exit( 1 )
 
 /*
  * Functions to support memory mapping:
@@ -113,7 +116,7 @@ static mapd_s *mmap_descriptors = static_mapd_array ;
  * try_memory_mapping attempts to setup the specified descriptor
  * for memory mapping. 
  * It returns FAILURE if it fails and SUCCESS if it is successful.
- * If HAS_MMAP is not defined, the function is defined to be FAILURE.
+ * If HAVE_MMAP is not defined, the function is defined to be FAILURE.
  *
  * Sets fields:
  *		memory_mapped:			 TRUE or FALSE
@@ -122,12 +125,9 @@ static mapd_s *mmap_descriptors = static_mapd_array ;
  *    file_offset, file_size, buffer_size
  *
  */
-PRIVATE status_e try_memory_mapping( fd, idp, stp )
-	int fd ;
-	register __sio_id_t *idp ;
-	struct stat *stp ;
+PRIVATE status_e try_memory_mapping( int fd, __sio_id_t *idp, struct stat *stp )
 {
-	int access ;
+	int access_f ;
 
 #ifdef EVENTS
 	EVENT( fd, EV_TRY_MEMORY_MAPPING ) ;
@@ -147,8 +147,8 @@ PRIVATE status_e try_memory_mapping( fd, idp, stp )
 	if ( ( ( stp->st_mode & S_IFMT ) != S_IFREG ) ||
 		  ( stp->st_size == 0 ) ||
 		  ( lseek( fd, (long)0, 1 ) != 0 ) ||
-		  ( ( access = fcntl( fd, F_GETFL, 0 ) ) == -1 ) ||
-		  ( ( access &= 0x3 ) != O_RDONLY && access != O_RDWR ) )
+		  ( ( access_f = fcntl( fd, F_GETFL, 0 ) ) == -1 ) ||
+		  ( ( access_f &= 0x3 ) != O_RDONLY && access_f != O_RDWR ) )
 	{
 		idp->memory_mapped = FALSE ;
 		return( FAILURE ) ;
@@ -163,10 +163,12 @@ PRIVATE status_e try_memory_mapping( fd, idp, stp )
 		page_size = getpagesize() ;
 		map_unit_size = page_size * PAGES_MAPPED ;
 		if ( map_unit_size < SIO_BUFFER_SIZE )
+		{
 			if ( map_unit_size > 0 && SIO_BUFFER_SIZE % map_unit_size == 0 )
 				map_unit_size = SIO_BUFFER_SIZE ;
 			else
 				map_unit_size = page_size ;
+		}
 	}
 	
 	MDP(fd)->file_offset = 0 ;
@@ -185,11 +187,7 @@ PRIVATE status_e try_memory_mapping( fd, idp, stp )
  * Sets fields: start, end, nextb
  * Also sets the file pointer
  */
-PRIVATE void buffer_setup( idp, fd, mu_cur, mu_next )
-	__sio_id_t *idp ;
-	int fd ;
-	struct map_unit *mu_cur ;
-	struct map_unit *mu_next ;
+PRIVATE void buffer_setup( __sio_id_t *idp, int fd, struct map_unit *mu_cur, struct map_unit *mu_next )
 {
 	off_t new_offset ;
 
@@ -217,17 +215,13 @@ PRIVATE void buffer_setup( idp, fd, mu_cur, mu_next )
  * Sets fields:
  *			start, end, nextb
  */
-status_e __sio_switch( idp, fd )
-	register __sio_id_t *idp ;
-	int fd ;
+status_e __sio_switch( __sio_id_t *idp, int fd )
 {
-	register mapd_s *mdp = MDP( fd ) ;
+	mapd_s *mdp = MDP( fd ) ;
 	struct map_unit *mu_cur, *mu_next ;
 	unsigned buffer_size = idp->buffer_size ;
 	char *buf_addr = idp->buf ;
 	int first_time = FIRST_TIME( idp ) ;
-	void buffer_setup() ;
-	status_e setup_read_buffer() ;
 
 #ifdef EVENTS
 	EVENT( fd, EV_SIO_SWITCH ) ;
@@ -285,22 +279,20 @@ status_e __sio_switch( idp, fd )
  *    or
  *			0 to indicate that mmap failed.
  */
-PRIVATE int initial_map( mdp, fd )
-	register mapd_s *mdp ;
-	int fd ;
+PRIVATE int initial_map( mapd_s *mdp, int fd )
 {
-	register caddr_t addr ;
-	register size_t requested_length = 2 * map_unit_size ;
-	register size_t mapped_length = MIN( mdp->file_size, requested_length ) ;
+	caddr_t addr ;
+	size_t requested_length = 2 * map_unit_size ;
+	size_t mapped_length = MIN( mdp->file_size, requested_length ) ;
 	size_t bytes_left ;
-	register size_t bytes_in_unit ;
+	size_t bytes_in_unit ;
 
 #ifdef EVENTS
 	EVENT( fd, EV_INITIAL_MAP ) ;
 #endif
 
 	addr = SIO_MMAP( CHAR_NULL, mapped_length, fd, 0 ) ;
-	if ( (int) addr == -1 )
+	if ( addr == MAP_FAILED )
 		return( 0 ) ;
 
 	SIO_MNEED( addr, mapped_length ) ;
@@ -344,13 +336,10 @@ PRIVATE int initial_map( mdp, fd )
  *		else
  *			unmap the unit
  */
-PRIVATE status_e map_unit( mdp, fd, mup )
-	register mapd_s *mdp ;
-	int fd ;
-	register struct map_unit *mup ;
+PRIVATE status_e map_unit( mapd_s *mdp, int fd, struct map_unit *mup )
 {
-	register size_t bytes_left = mdp->file_size - mdp->file_offset ;
-	register size_t bytes_to_map = MIN( bytes_left, map_unit_size ) ;
+	size_t bytes_left = mdp->file_size - mdp->file_offset ;
+	size_t bytes_to_map = MIN( bytes_left, map_unit_size ) ;
 
 #ifdef EVENTS
 	EVENT( fd, EV_MAP_UNIT ) ;
@@ -358,8 +347,8 @@ PRIVATE status_e map_unit( mdp, fd, mup )
 
 	if ( bytes_to_map > 0 )
 	{
-		if ( (int) SIO_MMAP( mup->addr, bytes_to_map,
-															fd, mdp->file_offset ) == -1 )
+		if ( SIO_MMAP( mup->addr, bytes_to_map,
+															fd, mdp->file_offset ) == MAP_FAILED )
 			return( FAILURE ) ;			/* XXX: need to do more ? */
 		
 		mup->valid_bytes = bytes_to_map ;
@@ -379,14 +368,12 @@ PRIVATE status_e map_unit( mdp, fd, mup )
 
 #define try_memory_mapping( x, y, z )				FAILURE
 
-#endif /* HAS_MMAP */
+#endif /* HAVE_MMAP */
 
 
-PRIVATE status_e setup_read_buffer( idp, buf_size )
-	register __sio_id_t *idp ;
-	unsigned buf_size ;
+PRIVATE status_e setup_read_buffer( __sio_id_t *idp, unsigned buf_size )
 {
-	register char *buf ;
+	char *buf ;
 
 	/*
 	 * First allocate space for 2 buffers: primary and auxiliary
@@ -404,10 +391,7 @@ PRIVATE status_e setup_read_buffer( idp, buf_size )
 }
 
 
-PRIVATE status_e init_input_stream( idp, fd, stp )
-	register __sio_id_t *idp ;
-	int fd ;
-	struct stat *stp ;
+PRIVATE status_e init_input_stream( __sio_id_t *idp, int fd, struct stat *stp )
 {
 #ifdef EVENTS
 	EVENT( fd, EV_INIT_INPUT_STREAM ) ;
@@ -439,13 +423,10 @@ PRIVATE status_e init_input_stream( idp, fd, stp )
 }
 
 
-PRIVATE status_e init_output_stream( odp, fd, stp )
-	register __sio_od_t *odp ;
-	int fd ;
-	struct stat *stp ;
+PRIVATE status_e init_output_stream( __sio_od_t *odp, int fd, struct stat *stp )
 {
-	register unsigned buf_size ;
-	register char *buf ;
+	unsigned buf_size ;
+	char *buf ;
 
 #ifdef EVENTS
 	EVENT( fd, EV_INIT_OUTPUT_STREAM ) ;
@@ -478,14 +459,13 @@ PRIVATE status_e init_output_stream( odp, fd, stp )
 }
 
 
-#ifndef HAS_ISATTY
+#ifndef HAVE_ISATTY
 
-#ifdef HAS_SYSVTTY
+#ifdef HAVE_SYSVTTY
 
 #include <termio.h>
 
-PRIVATE int isatty( fd )
-	int fd ;
+PRIVATE int isatty( int fd )
 {
 	struct termio t ;
 
@@ -494,14 +474,13 @@ PRIVATE int isatty( fd )
 	else
 		return( TRUE ) ;
 }
-#endif	/* HAS_SYSVTTY */
+#endif	/* HAVE_SYSVTTY */
 
-#ifdef HAS_BSDTTY
+#ifdef HAVE_BSDTTY
 
 #include <sgtty.h>
 
-PRIVATE int isatty( fd )
-	int fd ;
+PRIVATE int isatty( int fd )
 {
 	struct sgttyb s ;
 
@@ -510,9 +489,9 @@ PRIVATE int isatty( fd )
 	else
 		return( TRUE ) ;
 }
-#endif	/* HAS_BSDTTY */
+#endif	/* HAVE_BSDTTY */
 
-#endif	/* ! HAS_ISATTY */
+#endif	/* ! HAVE_ISATTY */
 
 
 /*
@@ -528,15 +507,9 @@ PRIVATE int isatty( fd )
  *	  SIO_ERR	if the file descriptor is not valid (sets errno)
  *   exits		if stream_type is not __SIO_INPUT_STREAM or __SIO_OUTPUT_STREAM
  */
-int __sio_init( dp, fd, stream_type )
-	register __sio_descriptor_t *dp ;
-	int fd ;
-	enum __sio_stream stream_type ;
+int __sio_init( __sio_descriptor_t *dp, int fd, enum __sio_stream stream_type )
 {
 	struct stat st ;
-#if !defined(linux) && !defined(BSD)
-	void terminate() ;
-#endif
 
 #ifdef EVENTS
 	EVENT( fd, EV_SIO_INIT ) ;
@@ -564,7 +537,7 @@ int __sio_init( dp, fd, stream_type )
 	dp->stream_type = stream_type ;
 	dp->initialized = TRUE ;
 
-#ifdef HAS_FINALIZATION_FUNCTION
+#ifdef HAVE_FINALIZATION_FUNCTION
 	if ( ! finalizer_installed )
 	{
 		if ( ! SIO_FINALIZE( sio_cleanup ) )
@@ -576,7 +549,7 @@ int __sio_init( dp, fd, stream_type )
 		else
 			finalizer_installed = TRUE ;
 	}
-#endif /* HAS_FINALIZATION_FUNCTION */
+#endif /* HAVE_FINALIZATION_FUNCTION */
 
 	return( 0 ) ;
 }
@@ -599,12 +572,10 @@ int __sio_init( dp, fd, stream_type )
  *		Number of bytes written
  *		SIO_ERR, if write(2) fails and no data were written
  */ 
-int __sio_writef( odp, fd )
-	register __sio_od_t *odp ;
-	int fd ;
+int __sio_writef( __sio_od_t *odp, int fd )
 {
-	register int b_in_buffer ;
-	register int cc_total = 0 ;
+	int b_in_buffer ;
+	int cc_total = 0 ;
 
 #ifdef EVENTS
 	EVENT( fd, EV_SIO_WRITEF ) ;
@@ -624,7 +595,7 @@ int __sio_writef( odp, fd )
 	
 	for ( ;; )
 	{
-		register int cc ;
+		int cc ;
 
 		cc = write( fd, odp->start, b_in_buffer ) ;
 		if ( cc == b_in_buffer )
@@ -666,11 +637,9 @@ int __sio_writef( odp, fd )
  * 		If it does not return SIO_ERR, it sets start, nextb, end
  *			If it returns SIO_ERR, it does not change anything
  */
-int __sio_readf( idp, fd )
-	register __sio_id_t *idp ;
-	int fd ;
+int __sio_readf( __sio_id_t *idp, int fd )
 {
-	register int cc ;
+	int cc ;
 
 #ifdef EVENTS
 	EVENT( fd, EV_SIO_READF ) ;
@@ -685,10 +654,10 @@ int __sio_readf( idp, fd )
 	if ( idp->tied_fd != SIO_NO_TIED_FD )
 		(void) __sio_writef( &__SIO_OD( idp->tied_fd ), idp->tied_fd ) ;
 
-#ifdef HAS_MMAP
+#ifdef HAVE_MMAP
 	if ( idp->memory_mapped )
 	{
-		register mapd_s *mdp = MDP( fd ) ;
+		mapd_s *mdp = MDP( fd ) ;
 
 		/*
 		 * The functions initial_map and map_unit may fail.
@@ -712,7 +681,7 @@ int __sio_readf( idp, fd )
 		}
 		else
 		{
-			register struct map_unit *mu_cur, *mu_next ;
+			struct map_unit *mu_cur, *mu_next ;
 
 			if ( idp->buf == mdp->first_unit.addr )
 			{
@@ -748,7 +717,7 @@ int __sio_readf( idp, fd )
 			return( cc ) ;
 		}
 	}
-#endif /* HAS_MMAP */
+#endif /* HAVE_MMAP */
 
 	for ( ;; )
 	{
@@ -778,12 +747,9 @@ int __sio_readf( idp, fd )
  * 	auxiliary buffer)
  *		Also, if successful, idp->nextb is set to idp->buf, idp->end is modified.
  */
-int __sio_extend_buffer( idp, fd, b_left )
-	register __sio_id_t *idp ;
-	int fd ;
-	register int b_left ;
+int __sio_extend_buffer( __sio_id_t *idp, int fd, int b_left )
 {
-	register int b_read ;
+	int b_read ;
 
 #ifdef EVENTS
 	EVENT( fd, EV_SIO_EXTEND_BUFFER ) ;
@@ -813,12 +779,10 @@ int __sio_extend_buffer( idp, fd, b_left )
  *
  * Return value: the number of bytes read.
  */
-int __sio_more( idp, fd )
-	register __sio_id_t *idp ;
-	int fd ;
+int __sio_more( __sio_id_t *idp, int fd )
 {
-	register int b_left = &idp->buf[ idp->buffer_size ] - idp->end ;
-	register int cc ;
+	int b_left = &idp->buf[ idp->buffer_size ] - idp->end ;
+	int cc ;
 
 #ifdef EVENTS
 	EVENT( fd, EV_SIO_MORE ) ;
@@ -847,10 +811,9 @@ int __sio_more( idp, fd )
 /*
  * Finalize a buffer by unmapping the file or freeing the malloc'ed memory
  */
-int Sdone( fd )
-	int fd ;
+int Sdone( int fd )
 {
-	register __sio_descriptor_t *dp = &__sio_descriptors[ fd ] ;
+	__sio_descriptor_t *dp = &__sio_descriptors[ fd ] ;
 
 #ifdef EVENTS
 	EVENT( fd, EV_SDONE ) ;
@@ -866,12 +829,12 @@ int Sdone( fd )
 	{
 		case __SIO_INPUT_STREAM:
 			{
-				register __sio_id_t *idp = IDP( dp ) ;
+				__sio_id_t *idp = IDP( dp ) ;
 
-#ifdef HAS_MMAP
+#ifdef HAVE_MMAP
 				if ( idp->memory_mapped )
 				{
-					register mapd_s *mdp = MDP( fd ) ;
+					mapd_s *mdp = MDP( fd ) ;
 
 					if ( mdp->first_unit.addr != CHAR_NULL )
 						(void) SIO_MUNMAP( mdp->first_unit.addr,
@@ -882,7 +845,7 @@ int Sdone( fd )
 					idp->memory_mapped = FALSE ;
 				}
 				else
-#endif	/* HAS_MMAP */
+#endif	/* HAVE_MMAP */
 					free( idp->buf - idp->buffer_size ) ;
 					idp->nextb = idp->end = NULL ;
 			}
@@ -890,7 +853,7 @@ int Sdone( fd )
 		
 		case __SIO_OUTPUT_STREAM:
 			{
-				register __sio_od_t *odp = ODP( dp ) ;
+				__sio_od_t *odp = ODP( dp ) ;
 
 				if ( Sflush( fd ) == SIO_ERR )
 					return( SIO_ERR ) ;
@@ -908,10 +871,7 @@ int Sdone( fd )
 }
 
 
-PRIVATE char *expand( area, old_size, new_size, is_static )
-	char *area ;
-	unsigned old_size, new_size ;
-	int is_static ;
+PRIVATE char *expand( char *area, unsigned old_size, unsigned new_size, int is_static )
 {
 	char *new_area ;
 
@@ -931,7 +891,7 @@ PRIVATE char *expand( area, old_size, new_size, is_static )
 #include <sys/time.h>
 #include <sys/resource.h>
 
-PRIVATE int get_fd_limit()
+PRIVATE int get_fd_limit(void)
 {
 #ifdef RLIMIT_NOFILE
 
@@ -954,7 +914,7 @@ PRIVATE int get_fd_limit()
  * There is no problem if the expansion of the SIO descriptors fails
  * (i.e. there is no need to undo anything).
  */
-int Smorefds()
+int Smorefds(void)
 {
 	char *p ;
 	int is_static ;
@@ -986,7 +946,7 @@ int Smorefds()
 	}
 #endif	/* EVENTS */
 
-#ifdef HAS_MMAP
+#ifdef HAVE_MMAP
 	old_size = n_descriptors * sizeof( mapd_s ) ;
 	new_size = n_fds * sizeof( mapd_s ) ;
 	is_static = ( mmap_descriptors == static_mapd_array ) ;
@@ -994,7 +954,7 @@ int Smorefds()
 	if ( p == NULL )
 		return( SIO_ERR ) ;
 	mmap_descriptors = (mapd_s *) p ;
-#endif	/* HAS_MMAP */
+#endif	/* HAVE_MMAP */
 	
 	old_size = n_descriptors * sizeof( __sio_descriptor_t ) ;
 	new_size = n_fds * sizeof( __sio_descriptor_t ) ;
@@ -1014,8 +974,7 @@ int Smorefds()
 /*
  * Enable recording of events for the specified file descriptor
  */
-int __sio_enable_events( fd )
-	int fd ;
+int __sio_enable_events( int fd )
 {
 	char *p = malloc( EVENT_ENTRIES * sizeof( short ) ) ;
 
@@ -1030,8 +989,7 @@ int __sio_enable_events( fd )
 /*
  * Disable recording of events for the specified file descriptor
  */
-void __sio_disable_events( fd )
-	int fd ;
+void __sio_disable_events( int fd )
 {
 	if ( __sio_events[ fd ].codes != NULL )
 	{
@@ -1044,10 +1002,7 @@ void __sio_disable_events( fd )
 /*
  * Move stored events to buf
  */
-int __sio_get_events( fd, buf, size )
-	int fd ;
-	char *buf ;
-	int size ;
+int __sio_get_events( int fd, char *buf, int size )
 {
 	events_s *evp = &__sio_events[ fd ] ;
 	int bufentries ;
@@ -1107,8 +1062,7 @@ int __sio_get_events( fd, buf, size )
  * Simple function that prints the string s at stderr and then calls
  * exit
  */
-PRIVATE void terminate( s )
-	char *s ;
+PRIVATE void terminate( char *s )
 {
 	(void) write( 2, s, strlen( s ) ) ;
 	(void) abort() ;
