@@ -1,38 +1,43 @@
 /*
  * (c) Copyright 1992, 1993 by Panagiotis Tsirigotis
- * All rights reserved.  The file named COPYRIGHT specifies the terms 
+ * All rights reserved.  The file named COPYRIGHT specifies the terms
  * and conditions for redistribution.
  */
 
 
-static char RCSid[] = "$Id: sprint.c,v 1.5 1995/09/10 18:35:09 chuck Exp $" ;
+static char RCSid[] = "$Id: sprint.c,v 1.1.1.1 1999/10/12 17:28:59 bbraun Exp $" ;
 
+#include <stdlib.h>
+#include <string.h>
 #include <ctype.h>
-#include <sys/param.h>
 
+#include "config.h"
 #include "sio.h"
 #include "impl.h"
 
+
 #ifndef WIDE_INT
-#define WIDE_INT							long
+#define WIDE_INT			long
 #endif
 
-typedef WIDE_INT 							wide_int ;
-typedef unsigned WIDE_INT 				u_wide_int ;
-typedef int 								bool_int ;
+typedef WIDE_INT 			wide_int ;
+typedef unsigned WIDE_INT		u_wide_int ;
+typedef int 				bool_int ;
 
-#define S_NULL								"(null)"
-#define S_NULL_LEN						6
+PRIVATE char *conv_10( wide_int num, bool_int is_unsigned, bool_int *is_negative, char *buf_end, int *len );
 
-#define FLOAT_DIGITS						6
-#define EXPONENT_LENGTH					10
+#define S_NULL				"(null)"
+#define S_NULL_LEN			6
+
+#define FLOAT_DIGITS			6
+#define EXPONENT_LENGTH			10
 
 /*
  * NUM_BUF_SIZE is the size of the buffer used for arithmetic conversions
  *
  * XXX: this is a magic number; do not decrease it
  */
-#define NUM_BUF_SIZE						512
+#define NUM_BUF_SIZE			512
 
 /*
  * The INS_CHAR macro inserts a character in the buffer and writes
@@ -48,47 +53,47 @@ typedef int 								bool_int ;
  *
  * NOTE: Evaluation of the c argument should not have any side-effects
  */
-#define INS_CHAR( c, sp, bep, odp, cc, fd )											\
-			{																						\
-				if ( sp < bep )																\
-				{																					\
-					*sp++ = c ;																	\
-					cc++ ;																		\
-				}																					\
-				else																				\
-				{																					\
-					if ( fd >= 0 )																\
-					{																				\
-						odp->nextb = sp ;														\
-						if ( __sio_writef( odp, fd ) != bep - odp->start )			\
-							return( ( cc != 0 ) ? cc : SIO_ERR ) ;						\
-						sp = odp->nextb ;														\
-						*sp++ = c ;																\
-						cc++ ;																	\
-					}																				\
-				}																					\
-				if ( __SIO_MUST_FLUSH( *odp, c ) && fd >= 0 ) 						\
-				{																					\
-					int b_in_buffer = sp - odp->start ;									\
-																									\
-					odp->nextb = sp ;															\
-					if ( __sio_writef( odp, fd ) != b_in_buffer )					\
-						return( cc ) ;															\
-					sp = odp->nextb ;															\
-				}																					\
-			}
+#define INS_CHAR( c, sp, bep, odp, cc, fd )				\
+	{								\
+		if ( sp < bep )						\
+		{							\
+			*sp++ = c ;					\
+			cc++ ;						\
+		}							\
+		else							\
+		{							\
+			if ( fd >= 0 )					\
+			{						\
+				odp->nextb = sp ;			\
+				if ( __sio_writef( odp, fd ) != bep - odp->start )	\
+					return( ( cc != 0 ) ? cc : SIO_ERR ) ;		\
+				sp = odp->nextb ;			\
+				*sp++ = c ;				\
+				cc++ ;					\
+			}						\
+		}							\
+		if ( __SIO_MUST_FLUSH( *odp, c ) && fd >= 0 )		\
+		{							\
+			int b_in_buffer = sp - odp->start ;		\
+									\
+			odp->nextb = sp ;				\
+			if ( __sio_writef( odp, fd ) != b_in_buffer )	\
+				return( cc ) ;				\
+			sp = odp->nextb ;				\
+		}							\
+	}
 
 
 
 #define NUM( c )			( c - '0' )
 
-#define STR_TO_DEC( str, num )									\
-									num = NUM( *str++ ) ;			\
-									while ( isdigit( *str ) )		\
-									{										\
-										num *= 10 ;						\
-										num += NUM( *str++ ) ;		\
-									}
+#define STR_TO_DEC( str, num )						\
+	num = NUM( *str++ ) ;						\
+	while ( isdigit( *str ) )					\
+	{								\
+		num *= 10 ;						\
+		num += NUM( *str++ ) ;					\
+	}
 
 /*
  * This macro does zero padding so that the precision
@@ -96,24 +101,24 @@ typedef int 								bool_int ;
  * adding '0's to the left of the string that is going
  * to be printed.
  */
-#define FIX_PRECISION( adjust, precision, s, s_len )				\
-					if ( adjust )												\
-						while ( s_len < precision )						\
-						{															\
-							*--s = '0' ;										\
-							s_len++ ;											\
-						}
+#define FIX_PRECISION( adjust, precision, s, s_len )			\
+	if ( adjust )							\
+		while ( s_len < precision )				\
+		{							\
+			*--s = '0' ;					\
+			s_len++ ;					\
+		}
 
 /*
  * Macro that does padding. The padding is done by printing
  * the character ch.
  */
-#define PAD( width, len, ch )			do														\
-												{														\
-													INS_CHAR( ch, sp, bep, odp, cc, fd ) ;	\
-													width-- ;										\
-												}														\
-												while ( width > len )
+#define PAD( width, len, ch )						\
+	do								\
+	{								\
+		INS_CHAR( ch, sp, bep, odp, cc, fd ) ;			\
+		width-- ;						\
+	} while ( width > len )
 
 /*
  * Prefix the character ch to the string str
@@ -122,10 +127,7 @@ typedef int 								bool_int ;
  */
 #define PREFIX( str, length, ch )	*--str = ch ; length++ ; has_prefix = YES
 
-#if defined(linux) || defined(BSD)
-PRIVATE char *conv_10( register wide_int num , register bool_int is_unsigned ,
-	register bool_int *is_negative , char *buf_end , register int *len ) ;
-#endif
+
 
 /*
  * Sprint is the equivalent of printf for SIO.
@@ -134,19 +136,16 @@ PRIVATE char *conv_10( register wide_int num , register bool_int is_unsigned ,
  *     - all floating point arguments are passed as doubles
  */
 /* VARARGS2 */
-int Sprint( fd, fmt, va_alist ) 
-	int fd ;
-	register char *fmt ;
-	va_dcl
+int Sprint( int fd, char *fmt, ...) 
 {
 	__sio_descriptor_t *dp = &__sio_descriptors[ fd ] ;
-	register __sio_od_t *odp = ODP( dp ) ;
-	register int cc ;
+	__sio_od_t *odp = ODP( dp ) ;
+	int cc ;
 	va_list ap ;
 
 	IO_SETUP( fd, dp, __SIO_OUTPUT_STREAM, SIO_ERR ) ;
 
-	va_start( ap ) ;
+	va_start( ap, fmt ) ;
 	cc = __sio_converter( odp, fd, fmt, ap ) ;
 	va_end( ap ) ;
 	return( cc ) ;
@@ -156,13 +155,10 @@ int Sprint( fd, fmt, va_alist )
 /*
  * This is the equivalent of vfprintf for SIO
  */
-int Sprintv( fd, fmt, ap )
-	int fd ;
-	char *fmt ;
-	va_list ap ;
+int Sprintv( int fd, char *fmt, va_list ap)
 {
 	__sio_descriptor_t *dp = &__sio_descriptors[ fd ] ;
-	register __sio_od_t *odp = ODP( dp ) ;
+	__sio_od_t *odp = ODP( dp ) ;
 
 	IO_SETUP( fd, dp, __SIO_OUTPUT_STREAM, SIO_ERR ) ;
 	return( __sio_converter( odp, fd, fmt, ap ) ) ;
@@ -175,26 +171,18 @@ int Sprintv( fd, fmt, ap )
  * The sign is returned in the is_negative argument (and is not placed
  * in buf).
  */
-PRIVATE char *conv_fp( format, num, add_dp, precision, is_negative, buf, len )
-	register char format ;
-	register double num ;
-	boolean_e add_dp ;			/* always add decimal point if YES */
-	int precision ;
-	bool_int *is_negative ;
-	char buf[] ;
-	int *len ;
+PRIVATE char *conv_fp( char format, double num, boolean_e add_dp, 
+   int precision, bool_int *is_negative, char buf[], int *len )
+	/* always add decimal point if YES */
 {
-	register char *s = buf ;
-	register char *p ;
+	char *s = buf ;
+	char *p = NULL ;
 	int decimal_point ;
-	char *ecvt(), *fcvt() ;
-	char *conv_10() ;
-	char *strcpy() ;
 		
 	if ( format == 'f' )
-		p = fcvt( num, precision, &decimal_point, is_negative ) ;
+		p = (char *)fcvt( num, precision, &decimal_point, is_negative ) ;
 	else /* either e or E format */
-		p = ecvt( num, precision+1, &decimal_point, is_negative ) ;
+		p = (char *)ecvt( num, precision+1, &decimal_point, is_negative ) ;
 
 	/*
 	 * Check for Infinity and NaN
@@ -238,7 +226,7 @@ PRIVATE char *conv_fp( format, num, add_dp, precision, is_negative, buf, len )
 	
 	if ( format != 'f' )
 	{
-		char temp[ EXPONENT_LENGTH ] ;				/* for exponent conversion */
+		char temp[ EXPONENT_LENGTH ] ;		/* for exponent conversion */
 		int t_len ;
 		bool_int exponent_is_negative ;
 
@@ -247,7 +235,7 @@ PRIVATE char *conv_fp( format, num, add_dp, precision, is_negative, buf, len )
 		if ( decimal_point != 0 )
 		{
 			p = conv_10( (wide_int)decimal_point, FALSE, &exponent_is_negative,
-												&temp[ EXPONENT_LENGTH ], &t_len ) ;
+					&temp[ EXPONENT_LENGTH ], &t_len ) ;
 			*s++ = exponent_is_negative ? '-' : '+' ;
 			
 			/*
@@ -280,18 +268,13 @@ PRIVATE char *conv_fp( format, num, add_dp, precision, is_negative, buf, len )
  * which is a pointer to the END of the buffer + 1 (i.e. if the buffer
  * is declared as buf[ 100 ], buf_end should be &buf[ 100 ])
  */
-PRIVATE char *conv_p2( num, nbits, format, buf_end, len )
-	register u_wide_int num ;
-	register int nbits ;
-	char format ;
-	char *buf_end ;
-	register int *len ;
+PRIVATE char *conv_p2( u_wide_int num, int nbits, char format, char *buf_end, int *len )
 {
-	register int mask = ( 1 << nbits ) - 1 ;
-	register char *p = buf_end ;
+	int mask = ( 1 << nbits ) - 1 ;
+	char *p = buf_end ;
 	static char low_digits[] = "0123456789abcdef" ;
 	static char upper_digits[] = "0123456789ABCDEF" ;
-	register char *digits = ( format == 'X' ) ? upper_digits : low_digits ;
+	char *digits = ( format == 'X' ) ? upper_digits : low_digits ;
 
 	do
 	{
@@ -318,15 +301,10 @@ PRIVATE char *conv_p2( num, nbits, format, buf_end, len )
  * which is a pointer to the END of the buffer + 1 (i.e. if the buffer
  * is declared as buf[ 100 ], buf_end should be &buf[ 100 ])
  */
-PRIVATE char *conv_10( num, is_unsigned, is_negative, buf_end, len )
-	register wide_int num ; 
-	register bool_int is_unsigned ;
-	register bool_int *is_negative ;
-	char *buf_end ;
-	register int *len ;
+PRIVATE char *conv_10( wide_int num, bool_int is_unsigned, bool_int *is_negative, char *buf_end, int *len )
 {
-	register char *p = buf_end ;
-	register u_wide_int magnitude ;
+	char *p = buf_end ;
+	u_wide_int magnitude ;
 
 	if ( is_unsigned )
 	{
@@ -361,7 +339,7 @@ PRIVATE char *conv_10( num, is_unsigned, is_negative, buf_end, len )
 	 */
 	do
 	{
-		register u_wide_int new_magnitude = magnitude / 10 ;
+		u_wide_int new_magnitude = magnitude / 10 ;
 
 		*--p = magnitude - new_magnitude*10 + '0' ;
 		magnitude = new_magnitude ;
@@ -376,29 +354,25 @@ PRIVATE char *conv_10( num, is_unsigned, is_negative, buf_end, len )
 /*
  * Do format conversion placing the output in odp
  */
-int __sio_converter( odp, fd, fmt, ap )
-	register __sio_od_t *odp ;
-	int fd ;
-	register char *fmt ;
-	va_list ap ;
+int __sio_converter( __sio_od_t *odp, int fd, char *fmt, va_list ap )
 {
-	register char *sp ;
-	register char *bep ;
-	register int cc = 0 ;
-	register int i ;
+	char *sp = NULL;
+	char *bep = NULL;
+	int cc = 0 ;
+	int i ;
 
-	register char *s ;
-	char *q ;
+	char *s = NULL;
+	char *q = NULL;
 	int s_len ;
 
-	register int min_width ;
-	int precision ;
+	int min_width = 0 ;
+	int precision = 0 ;
 	enum { LEFT, RIGHT } adjust ;
 	char pad_char ;
 	char prefix_char ;
 
 	double fp_num ;
-	wide_int i_num ;
+	wide_int i_num = 0 ;
 	u_wide_int ui_num ;
 
 	char num_buf[ NUM_BUF_SIZE ] ;
@@ -415,11 +389,6 @@ int __sio_converter( odp, fd, fmt, ap )
 	boolean_e adjust_width ;
 	bool_int is_negative ;
 
-	char *conv_10(), *conv_p2(), *conv_fp() ;
-	char *gcvt() ;
-	char *strchr() ;
-
-
 	sp = odp->nextb ;
 	bep = odp->buf_end ;
 
@@ -550,7 +519,7 @@ int __sio_converter( odp, fd, fmt, ap )
 					else
 						i_num = (wide_int) va_arg( ap, int ) ;
 					s = conv_10( i_num, (*fmt) == 'u', &is_negative,
-												&num_buf[ NUM_BUF_SIZE ], &s_len ) ;
+							&num_buf[ NUM_BUF_SIZE ], &s_len ) ;
 					FIX_PRECISION( adjust_precision, precision, s, s_len ) ;
 
 					if ( *fmt != 'u' )
@@ -571,7 +540,7 @@ int __sio_converter( odp, fd, fmt, ap )
 					else
 						ui_num = (u_wide_int) va_arg( ap, unsigned int ) ;
 					s = conv_p2( ui_num, 3, *fmt, 
-												&num_buf[ NUM_BUF_SIZE ], &s_len ) ;
+						&num_buf[ NUM_BUF_SIZE ], &s_len ) ;
 					FIX_PRECISION( adjust_precision, precision, s, s_len ) ;
 					if ( alternate_form && *s != '0' )
 					{
@@ -588,11 +557,11 @@ int __sio_converter( odp, fd, fmt, ap )
 					else
 						ui_num = (u_wide_int) va_arg( ap, unsigned int ) ;
 					s = conv_p2( ui_num, 4, *fmt,
-												&num_buf[ NUM_BUF_SIZE ], &s_len ) ;
+						&num_buf[ NUM_BUF_SIZE ], &s_len ) ;
 					FIX_PRECISION( adjust_precision, precision, s, s_len ) ;
 					if ( alternate_form && i_num != 0 )
 					{
-						*--s = *fmt ;			/* 'x' or 'X' */
+						*--s = *fmt ;		/* 'x' or 'X' */
 						*--s = '0' ;
 						s_len += 2 ;
 					}
@@ -614,7 +583,7 @@ int __sio_converter( odp, fd, fmt, ap )
 					}
 					pad_char = ' ' ;
 					break ;
-				
+
 
 				case 'f':
 				case 'e':
@@ -622,8 +591,8 @@ int __sio_converter( odp, fd, fmt, ap )
 					fp_num = va_arg( ap, double ) ;
 
 					s = conv_fp( *fmt, fp_num, alternate_form,
-							( adjust_precision == NO ) ? FLOAT_DIGITS : precision,
-													&is_negative, &num_buf[ 1 ], &s_len ) ;
+						( adjust_precision == NO ) ? FLOAT_DIGITS : precision,
+						&is_negative, &num_buf[ 1 ], &s_len ) ;
 					if ( is_negative )
 						prefix_char = '-' ;
 					else if ( print_sign )
@@ -642,7 +611,7 @@ int __sio_converter( odp, fd, fmt, ap )
 					/*
 					 * We use &num_buf[ 1 ], so that we have room for the sign
 					 */
-					s = gcvt( va_arg( ap, double ), precision, &num_buf[ 1 ] ) ;
+					s = (char *)gcvt( va_arg( ap, double ), precision, &num_buf[ 1 ] ) ;
 					if ( *s == '-' )
 						prefix_char = *s++ ;
 					else if ( print_sign )
@@ -692,7 +661,7 @@ int __sio_converter( odp, fd, fmt, ap )
 
 					if ( sizeof( char * ) <= sizeof( u_wide_int ) )
 						s = conv_p2( ui_num, 4, 'x', 
-												&num_buf[ NUM_BUF_SIZE ], &s_len ) ;
+						&num_buf[ NUM_BUF_SIZE ], &s_len ) ;
 					else
 					{
 						s = "%p" ;
