@@ -6,8 +6,8 @@
 
 static char RCSid[] = "$Id" ;
 
-char *malloc() ;
-
+#include "config.h"
+#include <stdlib.h>
 #include "ss_impl.h"
 
 PRIVATE int bmh_setup() ;
