@@ -6,8 +6,8 @@
 
 static char RCSid[] = "$Id: ss_kmp.c,v 1.1.1.1 1999/10/12 17:28:59 bbraun Exp $" ;
 
-char *malloc() ;
-
+#include <stdlib.h>
+#include "config.h"
 #include "ss_impl.h"
 
 PRIVATE int kmp_setup() ;
@@ -81,11 +81,11 @@ PRIVATE char *kmp_match( hp, str, len )
 	char			*str ;
 	int			len ;
 {
-	register int			i ;
+	register int		i ;
 	register next_int 	q ;
-	next_int					*next		= KMP_HEADER( hp )->next ;
-	char						*pattern = SS_PATTERN( hp ) ;
-	register int			patlen	= SS_PATLEN( hp ) ;
+	next_int		*next		= KMP_HEADER( hp )->next ;
+	char			*pattern = SS_PATTERN( hp ) ;
+	register int		patlen	= SS_PATLEN( hp ) ;
 
 	/*
 	 * As a special case, we consider pattern[ -1..0 ] to be the empty string.
