@@ -6,8 +6,8 @@
 
 static char RCSid[] = "$Id: ss_sbm.c,v 1.1.1.1 1999/10/12 17:28:59 bbraun Exp $" ;
 
-char *malloc() ;
-
+#include <stdlib.h>
+#include "config.h"
 #include "ss_impl.h"
 #include "ss_sbm.h"
 
