@@ -5,56 +5,60 @@
  */
 
 static char RCSid[] = "$Id: strparse.c,v 1.1.1.1 1999/10/12 17:28:59 bbraun Exp $" ;
-static char version[] = VERSION ;
+#include "config.h"
+#ifdef STR_VERSION
+static char version[] = STR_VERSION ;
+#endif
 
 #include <string.h>
 #include <stdlib.h>
+#include <unistd.h>
 
 #include "str.h"
 #include "strparse.h"
+#include "sio.h"
 
 int str_errno ;
 
 
-PRIVATE char *new_string( s )
-	register char *s ;
+char *new_string( register char *s )
 {
-	register char *p = (char *) malloc( (unsigned)strlen( s ) + 1 ) ;
-
-	return( p ? strcpy( p, s ) : p ) ;
+   if ( s )
+      return strdup( s ) ;
+   else
+      return 0;
 }
 
 
-str_h str_parse( str, separ, flags, errnop )
-	register char	*str ;
-	char				*separ ;
-	int				flags ;
-	int				*errnop ;
+str_h str_parse( register char *str, char *separ, int flags, int *errnop )
 {
 	register struct str_handle *hp ;
 	int *errp = ( errnop == NULL ) ? &str_errno : errnop ;
 
-	if ( separ == NULL )
+	if ( separ == NULL ) {
 		HANDLE_ERROR( flags, NULL, errp, STR_ENULLSEPAR,
 								"STR str_parse: NULL separator\n" ) ;
+	}
 
 	hp = (struct str_handle *) malloc( sizeof( struct str_handle ) ) ;
-	if ( hp == NULL )
+	if ( hp == NULL ) {
 		HANDLE_ERROR( flags, NULL, errp, STR_ENOMEM,
 								"STR str_parse: malloc failed\n" ) ;
+	}
 
 	hp->string = str ;
 	hp->pos = str ;
 	hp->separator = new_string( separ ) ;
-	if ( hp->separator == NULL )
+	if ( hp->separator == NULL ) {
 		if ( flags & STR_RETURN_ERROR )
 		{
 			free( (char *) hp ) ;
 			*errp = STR_ENOMEM ;
 			return( NULL ) ;
-		}
-		else
+		} else {
 			TERMINATE( "STR str_parse: malloc failed\n" ) ;
+		}
+	}
 	
 	hp->flags = flags ;
 	hp->errnop = errp ;
@@ -63,8 +67,7 @@ str_h str_parse( str, separ, flags, errnop )
 }
 
 
-void str_endparse( handle )
-	str_h handle ;
+void str_endparse( str_h handle )
 {
 	register struct str_handle *hp = (struct str_handle *) handle ;
 
@@ -76,15 +79,14 @@ void str_endparse( handle )
 /*
  * Change the string
  */
-int str_setstr( handle, newstr )
-	str_h handle ;
-	char *newstr ;
+int str_setstr( str_h handle, char *newstr )
 {
 	register struct str_handle *hp = (struct str_handle *) handle ;
 	
-	if ( newstr == NULL )
+	if ( newstr == NULL ) {
 		HANDLE_ERROR( hp->flags, STR_ERR, hp->errnop, STR_ENULLSTRING,
 								"STR str_setstr: NULL string\n" ) ;
+	}
 	
 	hp->string = newstr ;
 	hp->pos = newstr ;
@@ -97,20 +99,20 @@ int str_setstr( handle, newstr )
 /*
  * Change the separator
  */
-int str_separator( handle, separator )
-	str_h handle ;
-	char *separator ;
+int str_separator( str_h handle, char *separator )
 {
 	register struct str_handle *hp = (struct str_handle *) handle ;
 	char *new_separator ;
 
-	if ( separator == NULL )
+	if ( separator == NULL ) {
 		HANDLE_ERROR( hp->flags, STR_ERR, hp->errnop, STR_ENULLSEPAR,
 								"STR str_separator: NULL separator\n" ) ;
+	}
 	new_separator = new_string( separator ) ;
-	if ( new_separator == NULL )
+	if ( new_separator == NULL ) {
 		HANDLE_ERROR( hp->flags, STR_ERR, hp->errnop, STR_ENOMEM,
 			"STR str_separator: malloc failed\n" ) ;
+	}
 
 	free( hp->separator ) ;
 	hp->separator = new_separator ;
@@ -118,8 +120,7 @@ int str_separator( handle, separator )
 }
 
 
-char *str_nextpos( handle )
-	str_h handle ;
+char *str_nextpos( str_h handle )
 {
 	struct str_handle *hp = (struct str_handle *) handle ;
 
@@ -130,16 +131,15 @@ char *str_nextpos( handle )
 }
 
 
-char *str_component( handle )
-	str_h handle ;
+char *str_component( str_h handle )
 {
-	register char						*start ;
-	register char						*last ;
-	register int						sep_count ;
-	char									*retval ;
-	int									last_char ;
-	register struct str_handle		*hp			= (struct str_handle *) handle ;
-	register int						first_call	= ( hp->pos == hp->string ) ;
+	register char			*start ;
+	register char			*last ;
+	register int			sep_count ;
+	char				*retval ;
+	int				last_char ;
+	register struct str_handle	*hp	= (struct str_handle *) handle ;
+	register int			first_call	= ( hp->pos == hp->string ) ;
 
 	if ( hp->no_more )
 		return( NULL ) ;
@@ -182,7 +182,7 @@ char *str_component( handle )
 	/*
 	 * At this point, the following variables must be set:
 	 *		start:	beginning of component
-	 *		last:   	end of component + 1
+	 *		last:   end of component + 1
 	 *
 	 * If STR_MALLOC is set, allocate space for the new string.
 	 *
@@ -194,9 +194,10 @@ char *str_component( handle )
 		int len = last - start ;
 
 		retval = malloc( (unsigned)len + 1 ) ;
-		if ( retval == NULL )
+		if ( retval == NULL ) {
 			HANDLE_ERROR( hp->flags, NULL, hp->errnop, STR_ENOMEM,
-											"STR str_component: malloc failed\n" ) ;
+				"STR str_component: malloc failed\n" ) ;
+		}
 		strncpy( retval, start, len )[ len ] = '\0' ;
 	}
 	else
@@ -213,4 +214,3 @@ char *str_component( handle )
 	return( retval ) ;
 }
 
-
