@@ -4,6 +4,8 @@
  * and conditions for redistribution.
  */
 
+#ifndef __STRPARSE_H
+#define __STRPARSE_H
 
 /*
  * $Id: strparse.h,v 1.1.1.1 1999/10/12 17:28:59 bbraun Exp $
@@ -19,7 +21,7 @@ struct str_handle
    int no_more ;
 } ;
 
-int str_errno ;
+/* extern int str_errno ; */
 
 #ifndef NULL
 #define NULL         0
@@ -51,4 +53,5 @@ int str_errno ;
             else                                            \
                TERMINATE( msg )
 
+#endif
 
