@@ -6,17 +6,18 @@
 
 static char RCSid[] = "$Id: strprint.c,v 1.1.1.1 1999/10/12 17:28:59 bbraun Exp $" ;
 
+#include "config.h"
 #ifndef NO_SIO
 #include "sio.h"
 #endif
 
 #include "str.h"
 
-#define INT_NULL						((int *)0)
+#define INT_NULL			((int *)0)
 
 /*
- * The strx_* functions will never overwrite the buffer
- * The str_* functions may overwrite the buffer
+ * The strx_* functions will never over-run the buffer
+ * The str_* functions may over-run the buffer
  */
 
 /*
@@ -27,12 +28,7 @@ static char RCSid[] = "$Id: strprint.c,v 1.1.1.1 1999/10/12 17:28:59 bbraun Exp
  * This is the general purpose conversion function. It is invoked
  * by all the other str[x]_* functions
  */
-void strx_printv( ccp, buf, len, format, ap )
-	int *ccp ;
-	char *buf ;
-	int len ;
-	char *format ;
-	va_list ap ;
+void strx_printv( int *ccp, char *buf, int len, char *format, va_list ap )
 {
 #ifndef NO_SIO
 	__sio_od_t od ;
@@ -66,6 +62,11 @@ void strx_print( int *ccp, char *buf, int len, char *format, ... )
 {
 	va_list ap ;
 
+	if (len <= 0) {
+		*ccp = 0;
+		return;
+	}
+
 	va_start( ap, format ) ;
 	strx_printv( ccp, buf, len, format, ap ) ;
 	va_end( ap ) ;
@@ -76,6 +77,10 @@ char *strx_sprint( char *buf, int len, char *format, ... )
 {
 	va_list ap ;
 
+	if (len <= 0) {
+		*buf = 0;
+		return buf;
+	}
 	va_start( ap, format ) ;
 	strx_printv( INT_NULL, buf, len, format, ap ) ;
 	va_end( ap ) ;
@@ -89,6 +94,10 @@ char *strx_sprintv( buf, len, format, ap )
 	char *format ;
 	va_list ap ;
 {
+	if (len <= 0) {
+		*buf = 0;
+		return buf;
+	}
 	strx_printv( INT_NULL, buf, len, format, ap ) ;
 	return( buf ) ;
 }
@@ -99,6 +108,10 @@ int strx_nprint( char *buf, int len, char *format, ...)
 	int cc ;
 	va_list ap ;
 
+	if (len <= 0) {
+		*buf = 0;
+		return 0;
+	}
 	va_start( ap, format ) ;
 	strx_printv( &cc, buf, len, format, ap ) ;
 	va_end( ap ) ;
@@ -106,14 +119,14 @@ int strx_nprint( char *buf, int len, char *format, ...)
 }
 
 
-int strx_nprintv( buf, len, format, ap )
-	char *buf ;
-	int len ;
-	char *format ;
-	va_list ap ;
+int strx_nprintv( char *buf, int len, char *format, va_list ap )
 {
 	int cc ;
 
+	if (len <= 0) {
+		*buf = 0;
+		return 0;
+	}
 	strx_printv( &cc, buf, len, format, ap ) ;
 	return( cc ) ;
 }
@@ -134,11 +147,7 @@ void str_print( int *ccp, char *buf, char *format, ... )
 }
 
 
-void str_printv( ccp, buf, format, ap )
-	int *ccp ;
-	char *buf ;
-	char *format ;
-	va_list ap ;
+void str_printv( int *ccp, char *buf, char *format, va_list ap )
 {
 	strx_printv( ccp, buf, 0, format, ap ) ;
 }
@@ -155,10 +164,7 @@ char *str_sprint( char *buf, char *format, ... )
 }
 
 
-char *str_sprintv( buf, format, ap )
-	char *buf ;
-	char *format ;
-	va_list ap ;
+char *str_sprintv( char *buf, char *format, va_list ap )
 {
 	strx_printv( INT_NULL, buf, 0, format, ap ) ;
 	return( buf ) ;
@@ -177,11 +183,7 @@ int str_nprint( char *buf, char *format, ... )
 }
 
 
-
-int str_nprintv( buf, format, ap )
-	char *buf ;
-	char *format ;
-	va_list ap ;
+int str_nprintv( char *buf, char *format, va_list ap )
 {
 	int cc ;
 
