@@ -4,12 +4,15 @@
  * and conditions for redistribution.
  */
 
-static char RCSid[] = "$Id: strutil.c,v 3.1 1993/06/13 02:50:22 panos Exp $" ;
+static char RCSid[] = "$Id: strutil.c,v 1.1.1.1 1999/10/12 17:28:59 bbraun Exp $" ;
 
 
 #include <ctype.h>
+#include "config.h"
 
+#ifndef NULL
 #define NULL				0
+#endif
 
 
 #ifndef TRIVIAL_STR_FIND
@@ -18,13 +21,11 @@ static char RCSid[] = "$Id: strutil.c,v 3.1 1993/06/13 02:50:22 panos Exp $" ;
  * look for an instance of s2 in s1
  * Returns a pointer to the beginning of s2 in s1
  */
-char *str_find( str, sstr )
-	register char *str ;
-	register char *sstr ;
+char *str_find( register char *str, register char *sstr )
 {
    register int ssfc = *sstr++ ;    /* sub-string first char */
 
-	if ( ssfc == 0 )			/* empty string is always a match */
+	if ( ssfc == 0 )	/* empty string is always a match */
 		return( str ) ;
 
 	while ( *str )
@@ -60,9 +61,7 @@ char *str_find( str, sstr )
  * str_casefind is similar to str_find except that it ignores the
  * case of the alphabetic characters
  */
-char *str_casefind( str, sstr )
-	register char *str ;
-	char *sstr ;
+char *str_casefind( register char *str, char *sstr )
 {
 	register int ssfc = *sstr++ ;		/* sub-string first char */
 
@@ -117,9 +116,7 @@ char *str_casefind( str, sstr )
  * look for an instance of s2 in s1
  * Returns a pointer to the beginning of s2 in s1
  */
-char *str_find( s1, s2 )
-	char *s1 ;
-	char *s2 ;
+char *str_find( char *s1, char *s2 )
 {
    int i ;
    int l1 = strlen( s1 ) ;
@@ -132,9 +129,7 @@ char *str_find( s1, s2 )
 }
 
 
-char *str_casefind( s1, s2 )
-	char *s1 ;
-	char *s2 ;
+char *str_casefind( char *s1, char *s2 )
 {
    int i ;
    int l1 = strlen( s1 ) ;
