@@ -7,12 +7,15 @@
 static char RCSid[] = "$Id: ostimer.c,v 1.1.1.1 1999/10/12 17:28:59 bbraun Exp $" ;
 
 #include <stdio.h>
-#include <varargs.h>
-
-extern int errno ;
+#include <unistd.h>
+#include <stdarg.h>
+#include <stdlib.h>
+#include <string.h>
+#include <errno.h>
 
+#include "config.h"
 #include "timemacros.h"
-#include "defs.h"
+#include "timer_defs.h"
 #include "impl.h"
 #include "ostimer.h"
 
@@ -50,14 +53,13 @@ extern int errno ;
 
 #ifndef NO_TERMINATION
 
-PRIVATE void terminate( fmt, va_alist )
-   char *fmt ;
-   va_dcl
+PRIVATE void terminate( char *fmt, ... )
 {
    va_list ap ;
 
-   va_start( ap ) ;
+   va_start( ap, fmt ) ;
    (void) vfprintf( stderr, fmt, ap ) ;
+   va_end( ap );
    abort() ;
    _exit( 1 ) ;
 }
@@ -68,11 +70,9 @@ PRIVATE void terminate( fmt, va_alist )
 /*
  * Initialize the fields of struct timer that are used by the ostimer code
  */
-int __ostimer_newtimer( tp, type )
-	timer_s				*tp ;
-	enum timer_types	type ;
+int __ostimer_newtimer( timer_s *tp, enum timer_types type )
 {
-	ostimer_s			*otp = __ostimer_init( tp, type ) ;
+	ostimer_s	*otp = __ostimer_init( tp, type ) ;
 
 	if ( otp == OSTIMER_NULL )
 		return( TIMER_ERR ) ;
@@ -86,7 +86,6 @@ int __ostimer_newtimer( tp, type )
 
 
 
-
 /*
  * The following variables are used to handle the following scenario:
  *
@@ -129,19 +128,18 @@ static jmp_buf ret_env ;
  * If the array overflows, we arrange for another timer interrupt as
  * soon as possible to service remaining timers. The reason we don't
  * allocate the array using malloc is that malloc is not guaranteed
- * to be reentrant and tracking timing-related dynamic memory allocation 
+ * to be reentrant and tracking timing-related dynamic memory allocation
  * problems is guaranteed to be a nightmare.
  *
  * Notice that *all* timer interrupts are blocked during step 1.
  */
-void __ostimer_interrupt( otp )
-	register ostimer_s *otp ;
+void __ostimer_interrupt( register ostimer_s *otp )
 {
 	struct timeval		current_time ;
 	register timer_s	*tp ;
-	timer_s				*expired_timers[ MAX_EXPIRED ] ;
-	unsigned				n_expired = 0 ;
-	int					i ;
+	timer_s			*expired_timers[ MAX_EXPIRED ] ;
+	unsigned			n_expired = 0 ;
+	int				i ;
 
 	if ( timer_pq_head( otp->ost_timerq.tq_handle ) == TIMER_NULL )
 		return ;
@@ -157,10 +155,10 @@ void __ostimer_interrupt( otp )
 	{
 		tp = timer_pq_head( otp->ost_timerq.tq_handle ) ;
 
-		if ( tp == TIMER_NULL || TV_GT( tp->t_expiration, current_time ) ||
-																	n_expired == MAX_EXPIRED )
+		if ( tp == TIMER_NULL || (TV_GT( tp->t_expiration, current_time )) ||
+					n_expired == MAX_EXPIRED )
 			break ;
-		
+
 		tp = timer_pq_extract_head( otp->ost_timerq.tq_handle ) ;
 		if ( tp->t_state == TICKING )
 		{
@@ -211,14 +209,14 @@ void __ostimer_interrupt( otp )
 		struct itimerval itv ;
 
 		TV_ZERO( itv.it_interval ) ;
-		/* 
+		/*
 		 * Check if we had too many expired timers
 		 */
 		if ( TV_LE( tp->t_expiration, current_time ) )
 		{
 			itv.it_value.tv_sec = 0 ;
 			itv.it_value.tv_usec = 1 ;		/* schedule an interrupt ASAP */
-			/* XXX:	this trick will result in another call to 
+			/* XXX:	this trick will result in another call to
 			 *			ostimer_interrupt. So why don't we just call it
 			 *			recursively, instead of taking another timer interrupt ?
 			 */
@@ -238,7 +236,7 @@ void __ostimer_interrupt( otp )
 	 */
    for ( i = 0 ; i < n_expired ; i++ )
    {
-      tp = expired_timers[ i ] ;
+	 tp = expired_timers[ i ] ;
 		if ( __timer_invoke( tp ) != DESTROYED &&
 					! have_env && ( tp->t_action.ta_flags & TIMER_LONGJMP ) )
 		{
@@ -272,12 +270,11 @@ void __ostimer_interrupt( otp )
  * Notice that all timer interrupts are blocked while this function is running.
  * Therefore, none of the global variables checked can change.
  */
-PRIVATE void invoke_protocol( tp )
-	timer_s *tp ;
+PRIVATE void invoke_protocol( timer_s *tp )
 {
 	if ( __timer_invoke( tp ) != DESTROYED &&
-					call_level == 0 && ! have_env &&
-									( tp->t_action.ta_flags & TIMER_LONGJMP ) )
+				call_level == 0 && ! have_env &&
+							( tp->t_action.ta_flags & TIMER_LONGJMP ) )
 		longjmp( tp->t_action.ta_env, 1 ) ;
 }
 
@@ -289,11 +286,8 @@ PRIVATE void invoke_protocol( tp )
  * We also assume that no operations (block etc) are applied to the
  * timer while this function is running.
  */
-int __ostimer_add( otp, tp, itvp, time_type )
-	ostimer_s				*otp ;
-	register timer_s		*tp ;
-	struct itimerval		*itvp ;
-	enum timer_timetypes time_type ;
+int __ostimer_add( ostimer_s *otp, register timer_s *tp,
+		struct itimerval *itvp, enum timer_timetypes time_type )
 {
 	struct timeval		current_time ;
 	int					expired ;
@@ -362,9 +356,10 @@ int __ostimer_add( otp, tp, itvp, time_type )
 		invoke_protocol( tp ) ;
 	}
 
-	if ( timer_pq_insert( otp->ost_timerq.tq_handle, tp ) == PQ_ERR )
+	if ( timer_pq_insert( otp->ost_timerq.tq_handle, tp ) == PQ_ERR ) {
 		HANDLE_ERROR( tp->t_flags, TIMER_ERR, tp->t_errnop, TIMER_ECANTINSERT,
 			"TIMER __ostimer_add: can't insert timer in priority queue\n" ) ;
+	}
 
 	tp->t_state = TICKING ;
 
@@ -403,13 +398,11 @@ int __ostimer_add( otp, tp, itvp, time_type )
  * Remove the specified timer from the OS timer's queue
  * Timer interrupts should be blocked.
  */
-void __ostimer_remove( otp, tp )
-	ostimer_s	*otp ;
-	timer_s		*tp ;
+void __ostimer_remove( ostimer_s *otp, timer_s *tp )
 {
 	struct itimerval	itv ;
 	struct timeval		current_time ;
-	timer_s				*new_head_timer, *old_head_timer ;
+	timer_s			*new_head_timer, *old_head_timer ;
 
 	old_head_timer = timer_pq_head( otp->ost_timerq.tq_handle ) ;
 	timer_pq_delete( otp->ost_timerq.tq_handle, tp ) ;
