@@ -5,11 +5,18 @@
  */
 
 static char RCSid[] = "$Id: timer.c,v 1.2 1999/10/18 05:19:57 bbraun Exp $" ;
-static char *version = VERSION ;
+#include "config.h"
+#ifdef TIMER_VERSION
+static char *version = TIMER_VERSION ;
+#endif
 
+#include <stdlib.h>
+#include <unistd.h>
+#include <string.h>
 #include "timemacros.h"
+#include "timer_defs.h"
+#include "timer.h"
 #include "impl.h"
-#include "defs.h"
 
 #define TIMER_H_NULL					((timer_h)NULL)
 
@@ -17,30 +24,28 @@ static char *version = VERSION ;
 int timer_errno ;
 
 
-
 /*
  * Create a timer of the specified type.
  * Returns a timer handle
  */
-timer_h xtimer_create( type, flags, errnop )
-	enum timer_types	type ;
-	int					flags ;
-	int					*errnop ;
+timer_h xtimer_create( enum timer_types type, int flags, int *errnop )
 {
 	int		*errp = ( errnop != NULL ) ? errnop : &timer_errno ;
 	timer_s	*tp ;
 
 	if ( type != TIMER_REAL && type != TIMER_VIRTUAL && type != TIMER_PROF )
+	{
 			HANDLE_ERROR( flags, TIMER_H_NULL, errp, TIMER_EBADTYPE,
 							"TIMER timer_create: bad timer type\n" ) ;
-			
+	}
+
 	tp = TIMER_ALLOC() ;
 	if ( tp == NULL )
 	{
 		*errp = TIMER_ENOMEM ;
 		return( TIMER_H_NULL ) ;
 	}
-	
+
 	tp->t_state = INACTIVE ;
 	tp->t_act = IDLE ;
 	tp->t_blocked = FALSE ;
@@ -59,8 +64,7 @@ timer_h xtimer_create( type, flags, errnop )
 }
 
 
-void xtimer_destroy( handle )
-	timer_h	handle ;
+void xtimer_destroy( timer_h handle )
 {
 	timer_s	*tp = TP( handle ) ;
 
@@ -71,7 +75,7 @@ void xtimer_destroy( handle )
 		__ostimer_remove( tp->t_ostimer, tp ) ;
 		tp->t_state = DESTROYED ;
 	}
-	
+
 	if ( tp->t_act == IDLE || tp->t_act == PENDING )
 		TIMER_FREE( tp ) ;
 
@@ -79,11 +83,8 @@ void xtimer_destroy( handle )
 }
 
 
-int xtimer_start( handle, itvp, time_type, ap )
-	timer_h					handle ;
-	struct itimerval		*itvp ;
-	enum timer_timetypes time_type ;
-	struct timer_action	*ap ;
+int xtimer_start( timer_h handle, struct itimerval *itvp, enum timer_timetypes
+	time_type, struct timer_action *ap )
 {
 	int					result ;
 	int					ok_to_start ;
@@ -123,8 +124,7 @@ int xtimer_start( handle, itvp, time_type, ap )
 }
 
 
-void xtimer_stop( handle )
-	timer_h handle ;
+void xtimer_stop( timer_h handle )
 {
 	timer_s *tp = TP( handle ) ;
 
@@ -142,29 +142,27 @@ void xtimer_stop( handle )
 		tp->t_act = IDLE ;
 
 	tp->t_blocked = FALSE ;
-	
+
 	__ostimer_unblockall() ;
 }
 
 
-void xtimer_block( handle )
-	timer_h handle ;
+void xtimer_block( timer_h handle )
 {
 	timer_s *tp = TP( handle ) ;
 
 	__ostimer_blockall() ;
 
-	if ( tp->t_state == TICKING || 
-			tp->t_state == INACTIVE && 
-				( tp->t_act == PENDING || tp->t_act == SCHEDULED ) )
+	if ( tp->t_state == TICKING ||
+			(tp->t_state == INACTIVE &&
+				( tp->t_act == PENDING || tp->t_act == SCHEDULED ) ) )
 		tp->t_blocked = TRUE ;
 
 	__ostimer_unblockall() ;
 }
 
 
-void xtimer_unblock( handle )
-	timer_h handle ;
+void xtimer_unblock( timer_h handle )
 {
 	timer_s *tp = TP( handle ) ;
 
@@ -179,13 +177,12 @@ void xtimer_unblock( handle )
 			(void) __timer_invoke( tp ) ;
 		}
 	}
-	
+
 	__ostimer_unblockall() ;
 }
 
 
-unsigned xtimer_expirations( handle )
-	timer_h handle ;
+unsigned xtimer_expirations( timer_h handle )
 {
 	return( TP( handle )->t_count ) ;
 }
