@@ -4,32 +4,34 @@
  * and conditions for redistribution.
  */
 
-static char RCSid[] = "$Id: filelog.c,v 1.1 1995/11/11 23:08:58 chuck Exp root $" ;
+static char RCSid[] = "$Id: filelog.c,v 1.1.1.1 1999/10/12 17:28:59 bbraun Exp $" ;
 
 #include <sys/types.h>
 #include <sys/stat.h>
-#include <varargs.h>
+#include <stdarg.h>
 #include <fcntl.h>
 #include <time.h>
+#include <stdlib.h>
+#include <unistd.h>
+#include "config.h"
 #ifndef NO_SYSLOG
 #include <syslog.h>
 #else
 #define LOG_ALERT				0
 #endif
-#include <string.h>
 
 #include "sio.h"
-
+#include "str.h"
 #include "xlog.h"
 #include "impl.h"
 #include "filelog.h"
 
-PRIVATE int filelog_init() ;
-PRIVATE void filelog_fini() ;
-PRIVATE int filelog_control() ;
-PRIVATE int filelog_write() ;
-PRIVATE int filelog_parms() ;
-PRIVATE int limit_checks() ;
+PRIVATE int filelog_init(xlog_s *, va_list) ;
+PRIVATE void filelog_fini(xlog_s *) ;
+PRIVATE int filelog_control(xlog_s *, xlog_cmd_e, va_list) ;
+PRIVATE int filelog_write(xlog_s *, char buf[], int, int, va_list) ;
+PRIVATE int filelog_parms(xlog_e, va_list) ;
+PRIVATE int limit_checks(xlog_s *) ;
 
 struct xlog_ops __xlog_filelog_ops = 
 	{
@@ -41,35 +43,20 @@ struct xlog_ops __xlog_filelog_ops =
 	} ;
 
 
-PRIVATE int filelog_init( xp, ap )
-	xlog_s	*xp ;
-	va_list	ap ;
+PRIVATE int filelog_init( xlog_s *xp, va_list ap )
 {
 	int				fd ;
-	struct stat		st ;
 	struct filelog *flp ;
-	char				*filename	= va_arg( ap, char * ) ;
-	int				flags			= va_arg( ap, int ) ;
+	char				*filename;
+	int				flags;
+
+	filename = va_arg(ap, char *);
+	flags = va_arg(ap, int);
 
 	flp = NEW( struct filelog ) ;
 	if ( flp == NULL )
 		return( XLOG_ENOMEM ) ;
 
-	/*
-	 * For safety, don't open a logfile if it's a symlink - cdm
-	 * Open logfile if it does not exist or it's equal '/dev/tty'
-	 *  (used for debugging) - jw
-	 */
-	if (   lstat ( filename, &st ) == 0
-	    && ( st.st_mode & S_IFLNK ) == S_IFLNK
-	    && ( strcmp ( filename, "/dev/tty") != 0) )
-	{
-#ifndef NO_SYSLOG
-		syslog(LOG_WARNING, "Log file %s is a symlink - open abort", filename);
-#endif /* NO_SYSLOG */
-		return( XLOG_EOPEN ) ;
-	}
-
 	if ( flags & O_CREAT )
 		fd = open( filename, flags, va_arg( ap, int ) ) ;
 	else
@@ -90,8 +77,7 @@ PRIVATE int filelog_init( xp, ap )
 }
 
 
-PRIVATE void filelog_fini( xp )
-	xlog_s *xp ;
+PRIVATE void filelog_fini( xlog_s *xp )
 {
 	struct filelog *flp = FILELOG( xp ) ;
 
@@ -106,10 +92,7 @@ PRIVATE void filelog_fini( xp )
 
 
 
-PRIVATE int filelog_control( xp, cmd, ap )
-	xlog_s		*xp ;
-	xlog_cmd_e	cmd ;
-	va_list		ap ;
+PRIVATE int filelog_control( xlog_s *xp, xlog_cmd_e cmd, va_list ap )
 {
 	struct stat		st ;
 	struct filelog *flp		= FILELOG( xp ) ;
@@ -151,13 +134,21 @@ PRIVATE int filelog_control( xp, cmd, ap )
 					status = limit_checks( xp ) ;
 			}
 			break ;
+		case XLOG_LINK:
+		case XLOG_CALLBACK:
+		case XLOG_GETFLAG:
+		case XLOG_SETFLAG:
+		case XLOG_LEVEL:
+		case XLOG_FACILITY:
+		case XLOG_PREEXEC:
+		case XLOG_POSTEXEC:
+			break;
 	}
 	return( status ) ;
 }
 
 
-PRIVATE int limit_checks( xp )
-	xlog_s *xp ;
+PRIVATE int limit_checks( xlog_s *xp )
 {
 	struct filelog *flp = FILELOG( xp ) ;
 	char buf[ 100 ] ;
@@ -185,49 +176,24 @@ PRIVATE int limit_checks( xp )
 }
 
 
-PRIVATE int filelog_write( xp, buf, len, flags, ap )
-	xlog_s	*xp ;
-	char		buf[] ;
-	int		len ;
-	int		flags ;
-	va_list	ap ;
+PRIVATE int filelog_write( xlog_s *xp, char buf[], int len, int flags, va_list ap )
 {
 	struct filelog	*flp				= FILELOG( xp ) ;
 	int 				action_flags	= ( xp->xl_flags | flags ) ;
 	int				msglen			= 0 ;
 	char				*percent_m_pos ;
-	struct stat		st ;
 	int				cc ;
 	int				status ;
 	time_t 			current_time ;
 	struct tm		*tmp ;
-	time_t			time() ;
 
 	if ( flp->fl_state != FL_OPEN )
 		return( flp->fl_error ) ;
 
-	/*
-	 * For safety, don't write a logfile if it's a symlink - cdm
-	 * BOGUS - this should really be done by a separate daemon
-	 */
-
-#if 0
-	if ( fstat ( flp->fl_fd, &st ) != 0 )
-	{
-		flp->fl_state = FL_ERROR ;
-		flp->fl_error = XLOG_EFSTAT ;
-	}
-	if ( ( st.st_mode & S_IFLNK ) == S_IFLNK )
-	{
-		flp->fl_state = FL_ERROR ;
-		flp->fl_error = XLOG_EFSTAT ;
-	}
-#endif
-
 	(void) time( &current_time ) ;
 	tmp = localtime( &current_time ) ;
-	cc = Sprint( flp->fl_fd, "%d/%d/%d@%02d:%02d:%02d",
-							tmp->tm_year, tmp->tm_mon+1, tmp->tm_mday,
+	cc = Sprint( flp->fl_fd, "%02d/%d/%d@%02d:%02d:%02d",
+							tmp->tm_year%100, tmp->tm_mon+1, tmp->tm_mday,
 							tmp->tm_hour, tmp->tm_min, tmp->tm_sec ) ;
 	msglen += cc ;
 
@@ -296,8 +262,7 @@ PRIVATE int filelog_write( xp, buf, len, flags, ap )
 }
 
 
-PRIVATE int filelog_parms( ap )
-	va_list ap ;
+PRIVATE int filelog_parms( xlog_e type, va_list ap)
 {
 	return( XLOG_ENOERROR ) ;
 }
