@@ -9,6 +9,9 @@
  * $Id: filelog.h,v 1.1.1.1 1999/10/12 17:28:59 bbraun Exp $
  */
 
+#ifndef __FILELOG_H
+#define __FILELOG_H
+
 /*
  * The file can be either open or closed.
  * When the file is closed, the state is always FL_CLOSED.
@@ -38,3 +41,5 @@ struct filelog
 
 #define FILELOG( xp )			((struct filelog *)xp->xl_data)
 
+#endif
+
