@@ -9,7 +9,11 @@
  * $Id: impl.h,v 1.1.1.1 1999/10/12 17:28:59 bbraun Exp $
  */
 
+#ifndef __XLOG_IMPL_H
+#define __XLOG_IMPL_H
 
+#include <stdlib.h>  	/* For malloc() & free() prototypes */
+#include <stdarg.h>
 #define DEFINE_LINK_TYPE( type, name )		struct { type *next, *prev ; } name
 
 
@@ -59,11 +63,11 @@ struct xlog
 	DEFINE_LINK_TYPE( struct xlog, xl_other_users ) ;
 	struct xlog_ops
 	{
-		int 	(*init)		__ARGS( ( struct xlog *, va_list ) ) ;
-		void	(*fini) 		__ARGS( ( struct xlog * ) ) ;
-		int	(*write)		__ARGS( ( struct xlog *, char *, int, int, va_list ) ) ;
-		int	(*control)	__ARGS( ( struct xlog *, xlog_cmd_e, va_list ) ) ;
-		int	(*parms) 	__ARGS( ( va_list ) ) ;
+		int 	(*init)		( struct xlog *, va_list ) ;
+		void	(*fini) 		( struct xlog * ) ;
+		int	(*write)		( struct xlog *, char *, int, int, va_list ) ;
+		int	(*control)	( struct xlog *, xlog_cmd_e, va_list ) ;
+		int	(*parms) 	( xlog_e, va_list ) ;
 	} 					*xl_ops ;
 	void 				*xl_data ;
 } ;
@@ -98,9 +102,9 @@ typedef int bool_int ;
 
 #define PRIVATE		static
 
-char *__xlog_add_errno() ;
-char *__xlog_explain_errno() ;
-char *__xlog_new_string() ;
+char *__xlog_add_errno(char *, int) ;
+char *__xlog_explain_errno(char *, unsigned *) ;
+char *__xlog_new_string(char *) ;
 
-char *malloc() ;
+#endif
 
