@@ -8,7 +8,8 @@
 /*
  * $Id: slog.h,v 1.1.1.1 1999/10/12 17:28:59 bbraun Exp $
  */
-
+#ifndef __SLOG_H
+#define __SLOG_H
 
 struct syslog
 {
@@ -23,8 +24,10 @@ struct syslog_parms
    int 		slp_logopts ;              /* used at openlog */
    int 		slp_facility ;
    char		*slp_ident ;					/* used at openlog */
-	bool_int slp_ident_is_malloced ;
+   bool_int slp_ident_is_malloced ;
 } ;
 
 #define SYSLOG( xp )         ((struct syslog *)xp->xl_data)
 
+#endif
+
