@@ -11,8 +11,11 @@ static char RCSid[] = "$Id: util.c,v 1.1.1.1 1999/10/12 17:28:59 bbraun Exp $" ;
 #include <stdio.h>
 #include <errno.h>
 
+#include "config.h"
+#include "str.h"
+
 #ifndef NUL
-#define NUL						'\0'
+#define NUL					'\0'
 #endif
 
 #ifndef NULL
@@ -22,9 +25,7 @@ static char RCSid[] = "$Id: util.c,v 1.1.1.1 1999/10/12 17:28:59 bbraun Exp $" ;
 /*
  * Search the given buffer for an occurrence of "%m"
  */
-char *__xlog_add_errno( buf, len )
-	char *buf ;
-	int len ;
+char *__xlog_add_errno( char *buf, int len )
 {
 	register char *s ;
 
@@ -35,17 +36,13 @@ char *__xlog_add_errno( buf, len )
 }
 
 
-
-char *__xlog_explain_errno( buf, size )
-	char *buf ;
-	unsigned *size ;
+char *__xlog_explain_errno( char *buf, unsigned *size )
 {
-	register int len ;
-
 	strx_nprint(buf, *size, "%s (errno = %d)", strerror(errno), errno);
 #if 0
 	if ( errno < sys_nerr )
 	{
+		register int len ;
 
 		(void) strncpy( buf, strerror( errno ), (int)*size ) ;
 		for ( len = 0 ; len < *size ; len++ )
@@ -54,19 +51,18 @@ char *__xlog_explain_errno( buf, size )
 		*size = len ;
 	}
 	else
-		len = strx_nprint( buf, *size, "errno = %d", errno ) ;
+		(void) strx_nprint( buf, *size, "errno = %d", errno ) ;
 #endif
 	return( buf ) ;
 }
 
 
-char *__xlog_new_string( s )
-	char *s ;
+char *__xlog_new_string( char *s )
 {
-	unsigned size = strlen( s ) + 1 ;
-	char *p = malloc( size ) ;
-
-	return( ( p != NULL ) ? strcpy( p, s ) : p ) ;
+   if ( s )
+      return strdup( s ) ;
+   else
+      return 0;
 }
 
 
