@@ -4,16 +4,18 @@
  * and conditions for redistribution.
  */
 
-static char RCSid[] = "$Id: xlog.c,v 2.1 1993/05/06 07:39:39 panos Exp $" ;
-static char version[] = VERSION ;
+static char RCSid[] = "$Id: xlog.c,v 1.1.1.1 1999/10/12 17:28:59 bbraun Exp $" ;
+#include "config.h"
+#ifdef XLOG_VERSION
+static char version[] = XLOG_VERSION ;
+#endif
 
-#include <varargs.h>
+#include <stdlib.h>
+#include <stdarg.h>
 
 #include "xlog.h"
 #include "impl.h"
 
-char *malloc() ;
-
 extern struct xlog_ops __xlog_filelog_ops ;
 #ifndef NO_SYSLOG
 extern struct xlog_ops __xlog_syslog_ops ;
@@ -40,14 +42,13 @@ static struct lookup_table ops_lookup_table[] =
 			(*(xp)->xl_callback)( (xlog_h)(xp), status, (xp)->xl_callback_arg )
 
 
-PRIVATE void xlog_link() ;
-PRIVATE void xlog_unlink() ;
+PRIVATE void xlog_link( xlog_s *client, xlog_s *server ) ;
+PRIVATE void xlog_unlink( xlog_s *xp ) ;
 
 
-PRIVATE struct xlog_ops *xlog_ops_lookup( type )
-	register xlog_e type ;
+PRIVATE struct xlog_ops *xlog_ops_lookup( xlog_e type )
 {
-	register struct lookup_table *ltp ;
+	struct lookup_table *ltp ;
 
 	for ( ltp = &ops_lookup_table[ 0 ] ; ltp->ops ; ltp++ )
 		if ( ltp->type == type )
@@ -58,11 +59,7 @@ PRIVATE struct xlog_ops *xlog_ops_lookup( type )
 
 
 /* VARARGS3 */
-xlog_h xlog_create( type, id, flags, va_alist )
-	xlog_e	type ;
-	char		*id ;
-	int		flags ;
-	va_dcl
+xlog_h xlog_create( xlog_e type, char *id, int flags, ... )
 {
 	xlog_s				*xp ;
 	va_list				ap ;
@@ -82,7 +79,7 @@ xlog_h xlog_create( type, id, flags, va_alist )
 	
 	if ( xops != NULL )
 	{
-		va_start( ap ) ;
+		va_start( ap, flags ) ;
 		xp->xl_ops = xops ;
 		status = XL_INIT( xp, ap ) ;
 		va_end( ap ) ;
@@ -104,8 +101,7 @@ xlog_h xlog_create( type, id, flags, va_alist )
 
 
 
-PRIVATE void xlog_link( client, server )
-	xlog_s *client, *server ;
+PRIVATE void xlog_link( xlog_s *client, xlog_s *server )
 {
 	client->xl_use = server ;
 	if ( server == NULL )
@@ -121,8 +117,7 @@ PRIVATE void xlog_link( client, server )
 }
 
 
-PRIVATE void xlog_unlink( xp )
-	xlog_s *xp ;
+PRIVATE void xlog_unlink( xlog_s *xp )
 {
 	xlog_s *server = xp->xl_use ;
 
@@ -157,26 +152,29 @@ PRIVATE void xlog_unlink( xp )
 }
 
 
-PRIVATE void xlog_flags( xp, cmd, ap )
-	xlog_s		*xp ;
-	xlog_cmd_e	cmd ;
-	va_list		ap ;
+PRIVATE void xlog_flags( xlog_s *xp, xlog_cmd_e cmd, ... )
 {
-	int	flag			= va_arg( ap, int ) ;
-	int	old_value	= ( ( xp->xl_flags & flag ) != 0 ) ;
-	int	*valp			= va_arg( ap, int * ) ;
+	va_list ap;
+	int	flag;
+	int	old_value;
+	int	*valp;
 
-	if ( cmd == XLOG_SETFLAG )
+	va_start(ap, cmd);
+	flag = va_arg( ap, int );
+	old_value = ((xp->xl_flags & flag) != 0);
+	valp = va_arg( ap, int * );
+	va_end(ap);
+	if ( cmd == XLOG_SETFLAG ) {
 		if ( *valp )
 			xp->xl_flags |= flag ;
 		else
 			xp->xl_flags &= ~flag ;
+	}
 	*valp = old_value ;
 }
 
 
-void xlog_destroy( xlog )
-	xlog_h xlog ;
+void xlog_destroy( xlog_h xlog )
 {
 	xlog_s *xp = XP( xlog ) ;
 
@@ -188,18 +186,13 @@ void xlog_destroy( xlog )
 
 
 /* VARARGS4 */
-void xlog_write( xlog, buf, len, flags, va_alist )
-	xlog_h	xlog ;
-	char		buf[] ;
-	int		len ;
-	int		flags ;
-	va_dcl
+void xlog_write( xlog_h xlog, char buf[], int len, int flags, ... )
 {
 	xlog_s	*xp = XP( xlog ) ;
 	va_list	ap ;
 	int		status ;
 
-	va_start( ap ) ;
+	va_start( ap, flags ) ;
 	status = XL_WRITE( xp, buf, len, flags, ap ) ;
 	va_end( ap ) ;
 
@@ -211,16 +204,13 @@ void xlog_write( xlog, buf, len, flags, va_alist )
 
 
 /* VARARGS2 */
-int xlog_control( xlog, cmd, va_alist )
-	xlog_h		xlog ;
-	xlog_cmd_e	cmd ;
-	va_dcl
+int xlog_control( xlog_h xlog, xlog_cmd_e cmd, ... )
 {
 	va_list	ap ;
 	xlog_s	*xp		= XP( xlog ) ;
 	int		status	= XLOG_ENOERROR ;
 
-	va_start( ap ) ;
+	va_start( ap, cmd ) ;
 
 	switch ( cmd )
 	{
@@ -249,23 +239,21 @@ int xlog_control( xlog, cmd, va_alist )
 }
 
 
-int xlog_parms( type, va_alist )
-	xlog_e type ;
-	va_dcl
+int xlog_parms( xlog_e type, ... )
 {
 	va_list	ap ;
 	int		status ;
 
-	va_start( ap ) ;
+	va_start( ap, type ) ;
 	switch ( type )
 	{
 #ifndef NO_SYSLOG
 		case XLOG_SYSLOG:
-			status = (*__xlog_syslog_ops.parms)( ap ) ;
+			status = (*__xlog_syslog_ops.parms)( type, ap ) ;
 			break ;
 #endif
 		case XLOG_FILELOG:
-			status = (*__xlog_filelog_ops.parms)( ap ) ;
+			status = (*__xlog_filelog_ops.parms)( type, ap ) ;
 			break ;
 		
 		default:
