@@ -36,16 +36,6 @@
  * Interface
  */
 
-#ifdef __ARGS
-#undef __ARGS
-#endif
-
-#ifdef PROTOTYPES
-#  define __ARGS( s )               s
-#else
-#  define __ARGS( s )               ()
-#endif
-
 typedef enum { XLOG_SYSLOG, XLOG_FILELOG } xlog_e ;
 
 typedef enum
@@ -65,10 +55,10 @@ typedef enum
 
 typedef void *xlog_h ;
 
-xlog_h xlog_create	__ARGS( ( xlog_e type, char *id, int flags, ... ) ) ;
-void xlog_destroy		__ARGS( ( xlog_h ) ) ;
-void xlog_write		__ARGS( ( xlog_h, char *buf, int len, int flags, ... ) ) ;
-int xlog_control		__ARGS( ( xlog_h, xlog_cmd_e, ... ) ) ;
-int xlog_parms			__ARGS( ( xlog_e type, ... ) ) ;
+xlog_h xlog_create	( xlog_e type, char *id, int flags, ... ) ;
+void xlog_destroy		( xlog_h ) ;
+void xlog_write		( xlog_h, char *buf, int len, int flags, ... ) ;
+int xlog_control		( xlog_h, xlog_cmd_e, ... ) ;
+int xlog_parms			( xlog_e type, ... ) ;
 
 #endif	/* __XLOG_H */
