@@ -1,5 +1,6 @@
 /*
  * (c) Copyright 1992 by Panagiotis Tsirigotis
+ * (c) Sections Copyright 1998-2001 by Rob Braun
  * All rights reserved.  The file named COPYRIGHT specifies the terms 
  * and conditions for redistribution.
  */
@@ -11,18 +12,19 @@
  * $Id: access.h,v 1.2 1999/10/13 02:51:03 bbraun Exp $
  */
 
+#include "connection.h"
 #include "defs.h"
 
 /*
  * These flags are used to form a mask for access_control.
  * The mask determines which checks will be performed.
  */
-#define CF_ADDRESS				1
-#define CF_TIME					2
-#define CF_SERVICE_LIMIT		3
-#define CF_PROCESS_LIMIT		4
+#define CF_ADDRESS            1
+#define CF_TIME               2
+#define CF_SERVICE_LIMIT      3
+#define CF_PROCESS_LIMIT      4
 
-typedef enum
+typedef enum 
    {
       AC_OK,               /* ok to start a server                         */
       AC_FORK,             /* tried to start a server but fork failed      */
@@ -30,8 +32,8 @@ typedef enum
       AC_TIME,             /* we do not accept requests at this time       */
       AC_SERVICE_LIMIT,    /* server limit would be exceeded for this      */
                            /* service                                      */
-		AC_PER_SOURCE_LIMIT, /* server limit would be exceeded for this      */
-		                     /* service and source address                   */
+      AC_PER_SOURCE_LIMIT, /* server limit would be exceeded for this      */
+                           /* service and source address                   */
       AC_PROCESS_LIMIT,    /* total process limit would be exceeded        */
       AC_LIBWRAP,
       AC_LOAD,
@@ -40,8 +42,11 @@ typedef enum
 
 extern struct name_value access_code_names[] ;
 
-#define access_explain( code )	nv_get_name( access_code_names, (int) (code) )
+#define access_explain( code )   nv_get_name( access_code_names, (int) (code) )
 
-access_e access_control() ;
+access_e access_control(struct service *, connection_s *, mask_t *) ;
+access_e parent_access_control(struct service *, connection_s *) ;
+void     scrub_global_access_lists( connection_s * );
+
+#endif   /* ACCESS_H */
 
-#endif	/* ACCESS_H */
