@@ -1,14 +1,17 @@
 /*
  * (c) Copyright 1992 by Panagiotis Tsirigotis
+ * (c) Sections Copyright 1998-2001 by Rob Braun
  * All rights reserved.  The file named COPYRIGHT specifies the terms 
  * and conditions for redistribution.
  */
 
 static char RCSid[] = "$Id: ident.c,v 1.1.1.1 1999/10/12 17:28:59 bbraun Exp $" ;
 
+#include "config.h"
 #include <sys/types.h>
 #include <sys/socket.h>
 #include <netinet/in.h>
+#include <arpa/inet.h>
 #include <netdb.h>
 #include <signal.h>
 #include <syslog.h>
@@ -17,26 +20,25 @@ static char RCSid[] = "$Id: ident.c,v 1.1.1.1 1999/10/12 17:28:59 bbraun Exp $"
 #include <fcntl.h>
 #include <string.h>
 #include <ctype.h>
+#include <stdlib.h>
+#include <unistd.h>
 
 #include "str.h"
 
 #include "defs.h"
 #include "sconst.h"
 #include "server.h"
+#include "servicedefs.h"
 
 PRIVATE char *get_line( int sd, register char *buf, unsigned bufsize );
 PRIVATE char *verify_line( char *line, unsigned local_port, unsigned remote_port );
 
-void msg() ;
-status_e write_buf() ;
 
+#define BUFSIZE			1024		/* RFC-1413 suggests 1000 */
 
-#define BUFSIZE					1024		/* RFC-1413 suggests 1000 */
+#define START_TIMER( t )	(void) alarm( t )
+#define STOP_TIMER()		(void) alarm( 0 )
 
-#define START_TIMER( t )		(void) alarm( t )
-#define STOP_TIMER()				(void) alarm( 0 )
-
-char *inet_ntoa() ;
 
 
 static jmp_buf env ;
@@ -51,9 +53,7 @@ PRIVATE void sigalrm_handler()
 /*
  * This function always runs in a forked process.
  */
-idresult_e log_remote_user( serp, timeout )
-	struct server *serp ;
-	unsigned timeout ;				/* in seconds */
+idresult_e log_remote_user( struct server *serp, unsigned timeout )
 {
 	static char				buf[ BUFSIZE ] ;
 	int						cc ;
@@ -149,11 +149,12 @@ idresult_e log_remote_user( serp, timeout )
 	sin_contact.sin_port = htons( IDENTITY_SERVICE_PORT ) ;
 #endif
 
-	if ( timeout )
+	if ( timeout ) {
 		if ( setjmp( env ) == 0 )
 			START_TIMER( timeout ) ;
 		else
 			return( IDR_TIMEDOUT ) ;
+	}
 
 	if ( connect( sd, SA( &sin_contact ), sizeof( sin_contact ) ) == -1 )
 	{
@@ -163,7 +164,7 @@ idresult_e log_remote_user( serp, timeout )
 	}
 
 	cc = strx_nprint( buf, sizeof( buf ),
-										"%d,%d\r\n", remote_port, local_port ) ;
+		"%d,%d\r\n", remote_port, local_port ) ;
 	if ( write_buf( sd, buf, cc ) == FAILED )
 	{
 		if ( timeout )
@@ -184,13 +185,8 @@ idresult_e log_remote_user( serp, timeout )
 	 */
 	if ( ( p = verify_line( buf, local_port, remote_port ) ) == NULL )
 	{
-#ifdef INET6
-		msg( LOG_ERR, func, "Bad line received from identity server at %s: %s",
-										xntoa( sin_remote ), buf ) ;
-#else
-		msg( LOG_ERR, func, "Bad line received from identity server at %s: %s",
-										inet_ntoa( sin_remote.sin_addr ), buf ) ;
-#endif
+		msg(LOG_ERR, func, "Bad line received from identity server at %s: %s",
+			xntoa( (struct sockaddr *)&sin_remote ), buf ) ;
 		return( IDR_BADRESP ) ;
 	}
 
@@ -199,13 +195,12 @@ idresult_e log_remote_user( serp, timeout )
 }
 
 
-PRIVATE char *verify_line( line, local_port, remote_port )
-	char			*line ;
-	unsigned 	local_port ;
-	unsigned 	remote_port ;
+PRIVATE char *verify_line( char *line, 
+                           unsigned local_port, 
+                           unsigned remote_port )
 {
-	register char	*p ;
-	register char	*start = line ;
+	char	*p ;
+	char	*start = line ;
 
 	/*
 	 * Verify port numbers
@@ -250,28 +245,24 @@ PRIVATE char *verify_line( line, local_port, remote_port )
 		return( NULL ) ;
 	return( p ) ;
 }
-
 	
 
 /*
  * Get a line terminated by CR-LF.
  * Replace the CR-LF with NUL.
  */
-PRIVATE char *get_line( sd, buf, bufsize )
-	int				sd ;
-	register char	*buf ;
-	unsigned 		bufsize ;
+PRIVATE char *get_line( int sd, char *buf, unsigned bufsize )
 {
-	int				size ;
-	register int	cc ;
-	register char	*p ;
-	register char	*s ;
-	char				*func = "get_line" ;
+	int	size ;
+	int	cc ;
+	char	*p ;
+	char	*s ;
+	char	*func = "get_line" ;
 
 	for ( p = buf, size = bufsize ; size > 0 ; p += cc, size -= cc )
 	{
 		cc = read( sd, p, size ) ;
-		if ( cc == -1 )
+		if ( cc == -1 ) {
 			if ( errno == EINTR )
 			{
 				cc = 0 ;
@@ -282,25 +273,28 @@ PRIVATE char *get_line( sd, buf, bufsize )
 				msg( LOG_ERR, func, "read: %m" ) ;
 				return( CHAR_NULL ) ;
 			}
+		}
+
 		if ( cc == 0 )
 		{
 			msg( LOG_ERR, func, "identd server reply missing ending CR-LF" ) ;
 			return( CHAR_NULL ) ;
 		}
 		for ( s = p ; s < p + cc ; s++ )
-			if ( *s == '\n' && s != buf && s[-1] == '\r' )
+		{
+			if ( (*s == '\n') && (s != buf) && (*(s-1) == '\r') )
 			{
-				s[-1] = NUL ;
+				*(s-1) = NUL ;
 				return( buf ) ;
 			}
+		}
 	}
 	msg( LOG_ERR, func, "Too much input from identity server" ) ;
 	return( CHAR_NULL ) ;
 }
 
 
-char *idresult_explain( result )
-	idresult_e result ;
+char *idresult_explain( idresult_e result )
 {
 	char *reason = "UNKNOWN" ;
 
