@@ -1,35 +1,35 @@
 /*
  * (c) Copyright 1992 by Panagiotis Tsirigotis
+ * (c) Sections Copyright 1998-2001 by Rob Braun
  * All rights reserved.  The file named COPYRIGHT specifies the terms 
  * and conditions for redistribution.
  */
 
-static char RCSid[] = "$Id: itox.c,v 1.5 1995/09/10 18:41:13 chuck Exp $" ;
+static char RCSid[] = "$Id: itox.c,v 1.3 1999/10/18 05:21:14 bbraun Exp $" ;
 
+#include "config.h"
 #define EQ( s1, s2 )					( strcmp( s1, s2 ) == 0 )
 
 #define NUL								'\0'
-#define NULL							0
 #define PRIVATE						static
 
 #define FIELD_WIDTH					15
 #define DAEMON_DIR_OPTION			"-daemon_dir"
 #define TCPD_NAME						"tcpd"
 
-#include <sys/param.h>
+#include <string.h>
 #include "sio.h"
 #include "str.h"
 #include "misc.h"
 
-#if defined(linux) || defined(BSD)
-PRIVATE void print_line( char *name, char *value ) ;
-PRIVATE char *next_word( char *description ) ;
-#endif
-
+#ifndef strchr
 char *strchr() ;
+#endif
 
 str_h strp ;
 int line_count ;
+PRIVATE void print_line( char *name, char *value );
+PRIVATE char *next_word( char *description );
 
 /*
  * This program works only as a filter.
@@ -111,10 +111,29 @@ int main( argc, argv )
 		print_line( "protocol", protocol ) ;
 
 		word = next_word( "wait/nowait" ) ;
-		print_line( "wait", EQ( word, "wait" ) ? "yes" : "no" ) ;
+		p = strchr(word, '.');
+		if (p != NULL)
+		{
+			Sprint( 2, "The entry for service %s/%s may be wrong, because\n", service, protocol);
+			Sprint( 2, "we can't convert .max option for wait/nowait field\n" ) ;
+			*p = '\0';
+			print_line( "wait", EQ( word, "wait" ) ? "yes" : "no" ) ;
+		}
+		else
+			print_line( "wait", EQ( word, "wait" ) ? "yes" : "no" ) ;
 
-		word = next_word( "user" ) ;
-		print_line( "user", word ) ;
+
+		word = next_word( "user[.group]" ) ;
+		p = strchr(word, '.');
+		if (p != NULL)
+		{
+			*p = '\0';
+			print_line( "user", word ) ;
+			word = ++p;
+			print_line( "group", word );
+		}
+		else
+			print_line( "user", word ) ;
 
 		word = next_word( "server" ) ;
 		if ( EQ( word, "internal" ) )
@@ -131,13 +150,13 @@ int main( argc, argv )
 			else
 			{
 				print_line( "type", "INTERNAL" ) ;
-				print_line( "id", make_string( 3, service, "-", socket_type ) ) ;
+				print_line( "id", make_string_cat( 3, service, "-", socket_type ) ) ;
 			}
 		}
 		else
 		{
 			char *server_path = word ;		/* from inetd.conf */
-			char *server_of_server_path = basename( server_path ) ;
+			char *server_of_server_path = (char *)basename( server_path ) ;
 			char *server_name = next_word( "server name" ) ;
 			char *server ;						/* for xinetd config file */
 
