@@ -1,5 +1,6 @@
 /*
  * (c) Copyright 1992 by Panagiotis Tsirigotis
+ * (c) Sections Copyright 1998-2001 by Rob Braun
  * All rights reserved.  The file named COPYRIGHT specifies the terms 
  * and conditions for redistribution.
  */
@@ -7,6 +8,8 @@
 #ifndef LOG_H
 #define LOG_H
 
+#include <sys/socket.h>
+
 /*
  * $Id: log.h,v 1.1.1.1 1999/10/12 17:28:59 bbraun Exp $
  */
@@ -23,35 +26,41 @@ typedef enum { L_NONE = 0, L_FILE, L_SYSLOG, L_COMMON_FILE } logtype_e ;
 
 struct filelog
 {
-   char		*fl_filename ;						/* always malloc'ed		*/
-	unsigned fl_soft_limit ;
-	unsigned fl_hard_limit ;
+   char     *fl_filename ;                  /* always malloc'ed      */
+   unsigned fl_soft_limit ;
+   unsigned fl_hard_limit ;
 } ;
 
-#define FILELOG_SIZE_CONTROL( flp )		( flp->fl_soft_limit != 0 )	
+#define FILELOG_SIZE_CONTROL( flp )      ( flp->fl_soft_limit != 0 )   
 
 
 struct syslog
 {
    int sl_facility ;
-	int sl_level ;
+   int sl_level ;
 } ;
 
 struct log
 {
-	logtype_e		l_type ;
-	struct filelog l_fl ;
-	struct syslog	l_sl ;
+   logtype_e      l_type ;
+   struct filelog l_fl ;
+   struct syslog  l_sl ;
 } ;
 
-#define log_get_type( lp )					(lp)->l_type
-#define log_set_type( lp, type )			(lp)->l_type = (type)
+#define log_get_type( lp )           (lp)->l_type
+#define log_set_type( lp, type )     (lp)->l_type = (type)
 
-#define log_filelog( lp )				(&(lp)->l_fl)
-#define log_syslog( lp )				(&(lp)->l_sl)
+#define log_filelog( lp )            (&(lp)->l_fl)
+#define log_syslog( lp )             (&(lp)->l_sl)
 
 status_e log_start() ;
 void log_end() ;
 
-#endif	/* LOG_H */
+char *xntoa(struct sockaddr *);
+void msg( int, char *, char *, ...);
+void out_of_memory(char *) ;
+void msg_suspend();
+void msg_resume();
+
+#endif   /* LOG_H */
 
