@@ -1,5 +1,6 @@
 /*
  * (c) Copyright 1992 by Panagiotis Tsirigotis
+ * (c) Sections Copyright 1998-2001 by Rob Braun
  * All rights reserved.  The file named COPYRIGHT specifies the terms 
  * and conditions for redistribution.
  */
@@ -12,18 +13,19 @@ extern char * filelog_option_arg_1 ;
 extern int syslog_option ;
 extern char * syslog_option_arg_1 ;
 extern int reuse_option ;
+extern int inet_compat ;
 extern int limit_option ;
 extern unsigned limit_option_arg_1 ;
 extern int loop_option ;
 extern unsigned loop_option_arg_1 ;
-extern int pid_option ;
+extern char *pid_file_option ;
 extern int logprocs_option ;
 extern unsigned logprocs_option_arg_1 ;
 extern int shutdownprocs_option ;
 extern unsigned shutdownprocs_option_arg_1 ;
 extern int cc_option ;
 extern unsigned cc_option_arg_1 ;
-extern u_long host_option_arg_1;
+extern int stayalive_option ;
 
 #define f_option_arg                   f_option_arg_1
 #define filelog_option_arg             filelog_option_arg_1
@@ -33,9 +35,9 @@ extern u_long host_option_arg_1;
 #define logprocs_option_arg            logprocs_option_arg_1
 #define shutdownprocs_option_arg       shutdownprocs_option_arg_1
 #define cc_option_arg                  cc_option_arg_1
-#define host_option_arg		       host_option_arg_1
 
 extern char *program_name ;
 
 void usage() ;
+int opt_recognize( int, char ** );
 
