@@ -1,5 +1,6 @@
 /*
  * (c) Copyright 1992 by Panagiotis Tsirigotis
+ * (c) Sections Copyright 1998-2001 by Rob Braun
  * All rights reserved.  The file named COPYRIGHT specifies the terms 
  * and conditions for redistribution.
  */
@@ -7,13 +8,20 @@
 #ifndef PARSE_H
 #define PARSE_H
 
+#include "conf.h"
 #include "defs.h"
 
 /*
  * $Id: parse.h,v 1.1.1.1 1999/10/12 17:28:59 bbraun Exp $
  */
 
-typedef enum { NO_ENTRY, BAD_ENTRY, SERVICE_ENTRY, DEFAULTS_ENTRY } entry_e ;
+typedef enum { NO_ENTRY, 
+               BAD_ENTRY, 
+               SERVICE_ENTRY, 
+               DEFAULTS_ENTRY, 
+               INCLUDE_ENTRY,
+               INCLUDEDIR_ENTRY
+} entry_e ;
 
 enum assign_op { SET_EQ, PLUS_EQ, MINUS_EQ } ;
 
@@ -31,8 +39,19 @@ struct attribute
 #define COMMENT_BEGIN            '#'
 #define KW_SERVICE					"service"
 #define KW_DEFAULTS					"defaults"
+#define KW_INCLUDE					"include"
+#define KW_INCLUDEDIR					"includedir"
 
 extern int line_count ;
 
+void parse_conf_file( int, struct configuration *);
+void parse_end() ;
+void parsemsg( int, char *, char *, ...);
+
+int line_has_only_1_char( char *, char );
+char *next_line( int );
+status_e parse_line( char *, char **, enum assign_op *, pset_h );
+void skip_entry( int );
+
 #endif	/* PARSE_H */
 
